"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from abbyy_document_ai.types import BaseModel
from abbyy_document_ai.utils import FieldMetadata, PathParamMetadata
from enum import Enum
import httpx
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PathParamDocumentConversionOutputFormat(str, Enum):
    r"""The format of the results."""

    HTML = "html"
    PDF = "pdf"


class DownloadDocumentConversionConvertedDocumentRequestTypedDict(TypedDict):
    document_id: str
    r"""The id of the document"""
    format_: PathParamDocumentConversionOutputFormat
    r"""The format of the results."""


class DownloadDocumentConversionConvertedDocumentRequest(BaseModel):
    document_id: Annotated[
        str,
        pydantic.Field(alias="documentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The id of the document"""

    format_: Annotated[
        PathParamDocumentConversionOutputFormat,
        pydantic.Field(alias="format"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The format of the results."""


class DownloadDocumentConversionConvertedDocumentResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    response_stream: NotRequired[httpx.Response]
    r"""The file containing the OCR results"""


class DownloadDocumentConversionConvertedDocumentResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    response_stream: Optional[httpx.Response] = None
    r"""The file containing the OCR results"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from abbyy_document_ai.types import BaseModel
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class BeginDangerousGoodsDeclarationFieldExtractionResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    headers: Dict[str, List[str]]
    documents: NotRequired[List[DocumentTypedDict]]
    r"""A list containing the document(s) sent for processing"""


class BeginDangerousGoodsDeclarationFieldExtractionResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    headers: Dict[str, List[str]]

    documents: Optional[List[Document]] = None
    r"""A list containing the document(s) sent for processing"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .inputsource import InputSource, InputSourceTypedDict
from abbyy_document_ai.types import BaseModel
from enum import Enum
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class BeginImageToTextTextExtractionRequestBodyLanguages(str, Enum):
    r"""The ISO 639-1 codes for the languages contained within the input source(s). If not provided, the default is English, French, German, and Spanish (en|fr|de|es)."""

    EN_FR_DE_ES = "en|fr|de|es"
    EN = "en"
    EN_ES = "en|es"
    EN_FR = "en|fr"
    EN_FR_NL = "en|fr|nl"
    EN_DE = "en|de"
    EN_JA = "en|ja"
    EN_ZH = "en|zh"


class BeginImageToTextTextExtractionRequestBodyOptionsTypedDict(TypedDict):
    preserve_document_structure: NotRequired[bool]
    r"""Set to true to enable structured output mode. This mode is focused on retaining the original document structure and appearance, including font styles, pictures, background color, etc., and is more focused on documents like agreements, contracts, specifications. If this option is set to false or not specified, text-only mode is used. Text-only mode is suitable for extracting all text from the input image, including small text areas of low quality. The document appearance and structure are ignored, pictures and tables are not detected. It is designed for the situations when you need to retrieve the data from the image for some further processing on your side, such as extracting data from bills, receipts or invoices."""
    languages: NotRequired[BeginImageToTextTextExtractionRequestBodyLanguages]
    r"""The ISO 639-1 codes for the languages contained within the input source(s). If not provided, the default is English, French, German, and Spanish (en|fr|de|es)."""
    handwriting: NotRequired[bool]
    r"""Whether the input source(s) contain handwriting. Defaults to false."""


class BeginImageToTextTextExtractionRequestBodyOptions(BaseModel):
    preserve_document_structure: Annotated[
        Optional[bool], pydantic.Field(alias="preserveDocumentStructure")
    ] = None
    r"""Set to true to enable structured output mode. This mode is focused on retaining the original document structure and appearance, including font styles, pictures, background color, etc., and is more focused on documents like agreements, contracts, specifications. If this option is set to false or not specified, text-only mode is used. Text-only mode is suitable for extracting all text from the input image, including small text areas of low quality. The document appearance and structure are ignored, pictures and tables are not detected. It is designed for the situations when you need to retrieve the data from the image for some further processing on your side, such as extracting data from bills, receipts or invoices."""

    languages: Optional[BeginImageToTextTextExtractionRequestBodyLanguages] = None
    r"""The ISO 639-1 codes for the languages contained within the input source(s). If not provided, the default is English, French, German, and Spanish (en|fr|de|es)."""

    handwriting: Optional[bool] = None
    r"""Whether the input source(s) contain handwriting. Defaults to false."""


class BeginImageToTextTextExtractionRequestBodyTypedDict(TypedDict):
    r"""Request to process a document using the image-to-text model"""

    input_source: InputSourceTypedDict
    r"""The source of the document(s) to be processed"""
    options: NotRequired[BeginImageToTextTextExtractionRequestBodyOptionsTypedDict]


class BeginImageToTextTextExtractionRequestBody(BaseModel):
    r"""Request to process a document using the image-to-text model"""

    input_source: Annotated[InputSource, pydantic.Field(alias="inputSource")]
    r"""The source of the document(s) to be processed"""

    options: Optional[BeginImageToTextTextExtractionRequestBodyOptions] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from abbyy_document_ai import models, utils
from abbyy_document_ai._hooks import HookContext
from abbyy_document_ai.types import OptionalNullable, UNSET
from abbyy_document_ai.utils import get_security_from_env
from jsonpath import JSONPath
from typing import Any, Dict, List, Mapping, Optional, Union


class Documents(BaseSDK):
    def list(
        self,
        *,
        cursor: Optional[str] = None,
        limit: Optional[int] = 10,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Optional[models.ListDocumentsResponse]:
        r"""List Documents

        This endpoint returns a list of documents that have been processed by the caller's organization. The list is paginated; use the [RFC 8288-compliant](https://www.rfc-editor.org/rfc/rfc8288) `Link` header on successful responses to obtain previous and/or next pages. The `Link` header may also contain links to the results for each document.

        :param cursor: The cursor to start the list from. If not provided, the list will start from the most recent documents.
        :param limit: The number of documents to return. The maximum allowed value is 25. If not provided, the list will return up to 10 documents.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListDocumentsRequest(
            cursor=cursor,
            limit=limit,
        )

        req = self._build_request(
            method="GET",
            path="/v1-preview/documents",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="listDocuments",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        def next_func() -> Optional[models.ListDocumentsResponse]:
            body = utils.unmarshal_json(http_res.text, Union[Dict[Any, Any], List[Any]])
            next_cursor = JSONPath("$[-1:].id").parse(body)

            if len(next_cursor) == 0:
                return None

            next_cursor = next_cursor[0]
            if next_cursor is None:
                return None

            return self.list(
                cursor=next_cursor,
                limit=limit,
                retries=retries,
            )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.ListDocumentsResponse(
                documents=utils.unmarshal_json(
                    http_res.text, Optional[List[models.Document]]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
                next=next_func,
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.BadRequestErrorData
            )
            raise models.BadRequestError(data=response_data)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.UnauthorizedErrorData
            )
            raise models.UnauthorizedError(data=response_data)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.TooManyRequestsErrorData
            )
            raise models.TooManyRequestsError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InternalServerErrorData
            )
            raise models.InternalServerError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list_async(
        self,
        *,
        cursor: Optional[str] = None,
        limit: Optional[int] = 10,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Optional[models.ListDocumentsResponse]:
        r"""List Documents

        This endpoint returns a list of documents that have been processed by the caller's organization. The list is paginated; use the [RFC 8288-compliant](https://www.rfc-editor.org/rfc/rfc8288) `Link` header on successful responses to obtain previous and/or next pages. The `Link` header may also contain links to the results for each document.

        :param cursor: The cursor to start the list from. If not provided, the list will start from the most recent documents.
        :param limit: The number of documents to return. The maximum allowed value is 25. If not provided, the list will return up to 10 documents.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListDocumentsRequest(
            cursor=cursor,
            limit=limit,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1-preview/documents",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="listDocuments",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        def next_func() -> Optional[models.ListDocumentsResponse]:
            body = utils.unmarshal_json(http_res.text, Union[Dict[Any, Any], List[Any]])
            next_cursor = JSONPath("$[-1:].id").parse(body)

            if len(next_cursor) == 0:
                return None

            next_cursor = next_cursor[0]
            if next_cursor is None:
                return None

            return self.list(
                cursor=next_cursor,
                limit=limit,
                retries=retries,
            )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.ListDocumentsResponse(
                documents=utils.unmarshal_json(
                    http_res.text, Optional[List[models.Document]]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
                next=next_func,
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.BadRequestErrorData
            )
            raise models.BadRequestError(data=response_data)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.UnauthorizedErrorData
            )
            raise models.UnauthorizedError(data=response_data)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.TooManyRequestsErrorData
            )
            raise models.TooManyRequestsError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InternalServerErrorData
            )
            raise models.InternalServerError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def delete(
        self,
        *,
        document_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteDocumentResponse:
        r"""Delete Document

        This endpoint deletes a document.

        :param document_id: The id of the document
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteDocumentRequest(
            document_id=document_id,
        )

        req = self._build_request(
            method="DELETE",
            path="/v1-preview/documents/{documentId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="deleteDocument",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return models.DeleteDocumentResponse(
                http_meta=models.HTTPMetadata(request=req, response=http_res)
            )
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.UnauthorizedErrorData
            )
            raise models.UnauthorizedError(data=response_data)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.NotFoundErrorData
            )
            raise models.NotFoundError(data=response_data)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.TooManyRequestsErrorData
            )
            raise models.TooManyRequestsError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InternalServerErrorData
            )
            raise models.InternalServerError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def delete_async(
        self,
        *,
        document_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteDocumentResponse:
        r"""Delete Document

        This endpoint deletes a document.

        :param document_id: The id of the document
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteDocumentRequest(
            document_id=document_id,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/v1-preview/documents/{documentId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="deleteDocument",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return models.DeleteDocumentResponse(
                http_meta=models.HTTPMetadata(request=req, response=http_res)
            )
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.UnauthorizedErrorData
            )
            raise models.UnauthorizedError(data=response_data)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.NotFoundErrorData
            )
            raise models.NotFoundError(data=response_data)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.TooManyRequestsErrorData
            )
            raise models.TooManyRequestsError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InternalServerErrorData
            )
            raise models.InternalServerError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .inputsource import InputSource, InputSourceTypedDict
from abbyy_document_ai.types import BaseModel
from enum import Enum
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DocumentConversionOutputFormat(str, Enum):
    r"""The format of the results."""

    HTML = "html"
    PDF = "pdf"


class Languages(str, Enum):
    r"""The ISO 639-1 codes for the languages contained within the input source(s). If not provided, the default is English, French, German, and Spanish (en|fr|de|es)."""

    EN_FR_DE_ES = "en|fr|de|es"
    EN = "en"
    EN_ES = "en|es"
    EN_FR = "en|fr"
    EN_FR_NL = "en|fr|nl"
    EN_DE = "en|de"
    EN_JA = "en|ja"
    EN_ZH = "en|zh"


class OptionsTypedDict(TypedDict):
    format_: DocumentConversionOutputFormat
    r"""The format of the results."""
    languages: NotRequired[Languages]
    r"""The ISO 639-1 codes for the languages contained within the input source(s). If not provided, the default is English, French, German, and Spanish (en|fr|de|es)."""
    handwriting: NotRequired[bool]
    r"""Whether the input source(s) contain handwriting. Defaults to false."""


class Options(BaseModel):
    format_: Annotated[DocumentConversionOutputFormat, pydantic.Field(alias="format")]
    r"""The format of the results."""

    languages: Optional[Languages] = None
    r"""The ISO 639-1 codes for the languages contained within the input source(s). If not provided, the default is English, French, German, and Spanish (en|fr|de|es)."""

    handwriting: Optional[bool] = None
    r"""Whether the input source(s) contain handwriting. Defaults to false."""


class BeginDocumentConversionDocumentConversionRequestBodyTypedDict(TypedDict):
    r"""Request to process a document using the document-conversion model"""

    input_source: InputSourceTypedDict
    r"""The source of the document(s) to be processed"""
    options: OptionsTypedDict


class BeginDocumentConversionDocumentConversionRequestBody(BaseModel):
    r"""Request to process a document using the document-conversion model"""

    input_source: Annotated[InputSource, pydantic.Field(alias="inputSource")]
    r"""The source of the document(s) to be processed"""

    options: Options



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class BusinessUnitTypedDict(TypedDict):
    r"""Business Unit (invoice recipient) details"""

    name: NotRequired[str]
    r"""The name of the business unit (invoice recipient)"""
    tax_id: NotRequired[str]
    r"""The tax payer registration number"""
    address: NotRequired[str]
    r"""The address of the business unit (invoice recipient). Used when no BusinessUnits data catalog is used or business unit not found in catalog."""
    country: NotRequired[str]
    r"""The country of the business unit (invoice recipient)"""
    state: NotRequired[str]
    r"""The state of the business unit (invoice recipient)"""
    state_or_province: NotRequired[str]
    r"""The state or province of the business unit (invoice recipient)"""
    city: NotRequired[str]
    r"""The city of the business unit (invoice recipient)"""
    street: NotRequired[str]
    r"""The street address of the business unit (invoice recipient)"""
    postal_code: NotRequired[str]
    r"""The postal code of the business unit (invoice recipient)"""
    zip_code: NotRequired[str]
    r"""The ZIP code of the business unit (invoice recipient)"""
    id: NotRequired[str]
    r"""The unique identifier of the business unit in an external system"""


class BusinessUnit(BaseModel):
    r"""Business Unit (invoice recipient) details"""

    name: Optional[str] = None
    r"""The name of the business unit (invoice recipient)"""

    tax_id: Annotated[Optional[str], pydantic.Field(alias="taxId")] = None
    r"""The tax payer registration number"""

    address: Optional[str] = None
    r"""The address of the business unit (invoice recipient). Used when no BusinessUnits data catalog is used or business unit not found in catalog."""

    country: Optional[str] = None
    r"""The country of the business unit (invoice recipient)"""

    state: Optional[str] = None
    r"""The state of the business unit (invoice recipient)"""

    state_or_province: Annotated[
        Optional[str], pydantic.Field(alias="stateOrProvince")
    ] = None
    r"""The state or province of the business unit (invoice recipient)"""

    city: Optional[str] = None
    r"""The city of the business unit (invoice recipient)"""

    street: Optional[str] = None
    r"""The street address of the business unit (invoice recipient)"""

    postal_code: Annotated[Optional[str], pydantic.Field(alias="postalCode")] = None
    r"""The postal code of the business unit (invoice recipient)"""

    zip_code: Annotated[Optional[str], pydantic.Field(alias="zipCode")] = None
    r"""The ZIP code of the business unit (invoice recipient)"""

    id: Optional[str] = None
    r"""The unique identifier of the business unit in an external system"""


class VendorTypedDict(TypedDict):
    r"""Vendor details"""

    name: NotRequired[str]
    r"""The vendor's name"""
    tax_id: NotRequired[str]
    r"""International tax payer registration number"""
    national_tax_id: NotRequired[str]
    r"""The tax payer registration number inside the country of origin"""
    iban: NotRequired[str]
    r"""The vendor's international bank account number"""
    bank_account: NotRequired[str]
    r"""The vendor's bank account"""
    bank_code: NotRequired[str]
    r"""The vendor's bank code"""
    swift_code: NotRequired[str]
    r"""The SWIFT code of the vendor"""
    address: NotRequired[str]
    r"""The vendor's address. Used when no Vendors data catalog is used or vendor not found in catalog."""
    country: NotRequired[str]
    r"""The vendor's country"""
    state: NotRequired[str]
    r"""The state of the business unit (invoice recipient)"""
    state_or_province: NotRequired[str]
    r"""The state or province of the business unit (invoice recipient)"""
    city: NotRequired[str]
    r"""The vendor's city"""
    street: NotRequired[str]
    r"""The vendor's street address"""
    postal_code: NotRequired[str]
    r"""The vendor's postal code"""
    zip_code: NotRequired[str]
    r"""The ZIP code of the business unit (invoice recipient)"""
    id: NotRequired[str]
    r"""The vendor's unique identifier in an external system"""


class Vendor(BaseModel):
    r"""Vendor details"""

    name: Optional[str] = None
    r"""The vendor's name"""

    tax_id: Annotated[Optional[str], pydantic.Field(alias="taxId")] = None
    r"""International tax payer registration number"""

    national_tax_id: Annotated[Optional[str], pydantic.Field(alias="nationalTaxId")] = (
        None
    )
    r"""The tax payer registration number inside the country of origin"""

    iban: Optional[str] = None
    r"""The vendor's international bank account number"""

    bank_account: Annotated[Optional[str], pydantic.Field(alias="bankAccount")] = None
    r"""The vendor's bank account"""

    bank_code: Annotated[Optional[str], pydantic.Field(alias="bankCode")] = None
    r"""The vendor's bank code"""

    swift_code: Annotated[Optional[str], pydantic.Field(alias="swiftCode")] = None
    r"""The SWIFT code of the vendor"""

    address: Optional[str] = None
    r"""The vendor's address. Used when no Vendors data catalog is used or vendor not found in catalog."""

    country: Optional[str] = None
    r"""The vendor's country"""

    state: Optional[str] = None
    r"""The state of the business unit (invoice recipient)"""

    state_or_province: Annotated[
        Optional[str], pydantic.Field(alias="stateOrProvince")
    ] = None
    r"""The state or province of the business unit (invoice recipient)"""

    city: Optional[str] = None
    r"""The vendor's city"""

    street: Optional[str] = None
    r"""The vendor's street address"""

    postal_code: Annotated[Optional[str], pydantic.Field(alias="postalCode")] = None
    r"""The vendor's postal code"""

    zip_code: Annotated[Optional[str], pydantic.Field(alias="zipCode")] = None
    r"""The ZIP code of the business unit (invoice recipient)"""

    id: Optional[str] = None
    r"""The vendor's unique identifier in an external system"""


class InvoiceDataTypedDict(TypedDict):
    due_date: NotRequired[date]
    r"""The date by which the invoice should be paid."""


class InvoiceData(BaseModel):
    due_date: Annotated[Optional[date], pydantic.Field(alias="dueDate")] = None
    r"""The date by which the invoice should be paid."""


class TaxRatesTypedDict(TypedDict):
    r"""Tax rate details for a specific rate"""

    net_amount: NotRequired[float]
    r"""Cost of goods or services without tax"""
    tax_amount: NotRequired[float]
    r"""Tax charged"""
    tax_rate: NotRequired[float]
    r"""Tax rate percentage"""


class TaxRates(BaseModel):
    r"""Tax rate details for a specific rate"""

    net_amount: Annotated[Optional[float], pydantic.Field(alias="netAmount")] = None
    r"""Cost of goods or services without tax"""

    tax_amount: Annotated[Optional[float], pydantic.Field(alias="taxAmount")] = None
    r"""Tax charged"""

    tax_rate: Annotated[Optional[float], pydantic.Field(alias="taxRate")] = None
    r"""Tax rate percentage"""


class InvoiceFieldsTaxesTypedDict(TypedDict):
    r"""Tax information"""

    total_net_amount: NotRequired[float]
    r"""The total cost of goods and services without tax"""
    total_taxes: NotRequired[float]
    r"""The total tax amount"""
    non_taxable_amount: NotRequired[float]
    r"""The amount on which no tax is payable"""
    tax_rates: NotRequired[List[TaxRatesTypedDict]]
    r"""Tax rates and amounts for different rates"""


class InvoiceFieldsTaxes(BaseModel):
    r"""Tax information"""

    total_net_amount: Annotated[
        Optional[float], pydantic.Field(alias="totalNetAmount")
    ] = None
    r"""The total cost of goods and services without tax"""

    total_taxes: Annotated[Optional[float], pydantic.Field(alias="totalTaxes")] = None
    r"""The total tax amount"""

    non_taxable_amount: Annotated[
        Optional[float], pydantic.Field(alias="nonTaxableAmount")
    ] = None
    r"""The amount on which no tax is payable"""

    tax_rates: Annotated[Optional[List[TaxRates]], pydantic.Field(alias="taxRates")] = (
        None
    )
    r"""Tax rates and amounts for different rates"""


class InvoiceTypeTypedDict(TypedDict):
    r"""The type of invoice document"""

    invoice: bool
    r"""Specifies the Invoice type of the invoice."""
    credit_note: bool
    r"""Specifies the Credit Note type of the invoice."""


class InvoiceType(BaseModel):
    r"""The type of invoice document"""

    invoice: bool
    r"""Specifies the Invoice type of the invoice."""

    credit_note: Annotated[bool, pydantic.Field(alias="creditNote")]
    r"""Specifies the Credit Note type of the invoice."""


class InvoiceFieldsPurchaseOrderTypedDict(TypedDict):
    r"""Purchase order details"""

    order_number: NotRequired[str]
    r"""The number of the purchase order"""
    total: NotRequired[float]
    r"""The cost of the goods or services listed in the purchase order"""
    order_checked: NotRequired[bool]
    r"""Indicates whether the order number is verified"""


class InvoiceFieldsPurchaseOrder(BaseModel):
    r"""Purchase order details"""

    order_number: Annotated[Optional[str], pydantic.Field(alias="orderNumber")] = None
    r"""The number of the purchase order"""

    total: Optional[float] = None
    r"""The cost of the goods or services listed in the purchase order"""

    order_checked: Annotated[Optional[bool], pydantic.Field(alias="orderChecked")] = (
        None
    )
    r"""Indicates whether the order number is verified"""


class LineItemsTypedDict(TypedDict):
    r"""Line item details"""

    order_number: NotRequired[str]
    r"""The number of the purchase order"""
    is_valid: NotRequired[bool]
    r"""Indicates whether the order number matches any checked order number in the Purchase Order group"""
    order_date: NotRequired[date]
    r"""The date when the purchase order was created"""
    position: NotRequired[float]
    r"""The number of the line item in the list"""
    article_number_vendor: NotRequired[str]
    r"""The article number or code in the vendor's database"""
    article_number_bu: NotRequired[str]
    r"""The article number or code in the business unit's database"""
    description: NotRequired[str]
    r"""A description of the line item"""
    quantity: NotRequired[float]
    r"""The number of units purchased"""
    unit_of_measurement: NotRequired[str]
    r"""The unit of measurement used for the goods"""
    unit_price: NotRequired[float]
    r"""The price of one item of goods"""
    discount_percentage: NotRequired[float]
    r"""The discount percentage on the initial line item price"""
    discount: NotRequired[float]
    r"""Discount applicable to the line item"""
    net_price: NotRequired[float]
    r"""The price of the line item without tax"""
    tax_rate: NotRequired[float]
    r"""The tax rate for the line item"""
    tax_amount: NotRequired[float]
    r"""The amount of tax payable on the line item"""
    tax_code: NotRequired[str]
    r"""The code of the tax"""
    total_price: NotRequired[float]
    r"""The price of the line item including tax"""
    currency: NotRequired[str]
    r"""The currency of the line item"""
    order_item_id: NotRequired[str]
    r"""The unique line item identifier"""


class LineItems(BaseModel):
    r"""Line item details"""

    order_number: Annotated[Optional[str], pydantic.Field(alias="orderNumber")] = None
    r"""The number of the purchase order"""

    is_valid: Annotated[Optional[bool], pydantic.Field(alias="isValid")] = None
    r"""Indicates whether the order number matches any checked order number in the Purchase Order group"""

    order_date: Annotated[Optional[date], pydantic.Field(alias="orderDate")] = None
    r"""The date when the purchase order was created"""

    position: Optional[float] = None
    r"""The number of the line item in the list"""

    article_number_vendor: Annotated[
        Optional[str], pydantic.Field(alias="articleNumberVendor")
    ] = None
    r"""The article number or code in the vendor's database"""

    article_number_bu: Annotated[
        Optional[str], pydantic.Field(alias="articleNumberBu")
    ] = None
    r"""The article number or code in the business unit's database"""

    description: Optional[str] = None
    r"""A description of the line item"""

    quantity: Optional[float] = None
    r"""The number of units purchased"""

    unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="unitOfMeasurement")
    ] = None
    r"""The unit of measurement used for the goods"""

    unit_price: Annotated[Optional[float], pydantic.Field(alias="unitPrice")] = None
    r"""The price of one item of goods"""

    discount_percentage: Annotated[
        Optional[float], pydantic.Field(alias="discountPercentage")
    ] = None
    r"""The discount percentage on the initial line item price"""

    discount: Optional[float] = None
    r"""Discount applicable to the line item"""

    net_price: Annotated[Optional[float], pydantic.Field(alias="netPrice")] = None
    r"""The price of the line item without tax"""

    tax_rate: Annotated[Optional[float], pydantic.Field(alias="taxRate")] = None
    r"""The tax rate for the line item"""

    tax_amount: Annotated[Optional[float], pydantic.Field(alias="taxAmount")] = None
    r"""The amount of tax payable on the line item"""

    tax_code: Annotated[Optional[str], pydantic.Field(alias="taxCode")] = None
    r"""The code of the tax"""

    total_price: Annotated[Optional[float], pydantic.Field(alias="totalPrice")] = None
    r"""The price of the line item including tax"""

    currency: Optional[str] = None
    r"""The currency of the line item"""

    order_item_id: Annotated[Optional[str], pydantic.Field(alias="orderItemId")] = None
    r"""The unique line item identifier"""


class InvoiceFieldsTypedDict(TypedDict):
    r"""Fields extracted from an invoice"""

    invoice_number: NotRequired[str]
    r"""The number of the invoice"""
    invoice_date: NotRequired[date]
    r"""The date when the invoice was issued"""
    total: NotRequired[float]
    r"""The total cost of goods or services"""
    currency: NotRequired[str]
    r"""The currency of the invoice"""
    business_unit: NotRequired[BusinessUnitTypedDict]
    r"""Business Unit (invoice recipient) details"""
    vendor: NotRequired[VendorTypedDict]
    r"""Vendor details"""
    delivery_date: NotRequired[date]
    r"""The date the goods were delivered or services performed"""
    invoice_data: NotRequired[InvoiceDataTypedDict]
    due_date: NotRequired[date]
    r"""The date by which the invoice should be paid"""
    reversed_charge: NotRequired[bool]
    r"""Indicates that a reverse charge is applied"""
    taxes: NotRequired[InvoiceFieldsTaxesTypedDict]
    r"""Tax information"""
    invoice_type: NotRequired[InvoiceTypeTypedDict]
    r"""The type of invoice document"""
    purchase_order: NotRequired[List[InvoiceFieldsPurchaseOrderTypedDict]]
    r"""Purchase order details"""
    line_items: NotRequired[List[LineItemsTypedDict]]
    r"""List of line items in the invoice"""


class InvoiceFields(BaseModel):
    r"""Fields extracted from an invoice"""

    invoice_number: Annotated[Optional[str], pydantic.Field(alias="invoiceNumber")] = (
        None
    )
    r"""The number of the invoice"""

    invoice_date: Annotated[Optional[date], pydantic.Field(alias="invoiceDate")] = None
    r"""The date when the invoice was issued"""

    total: Optional[float] = None
    r"""The total cost of goods or services"""

    currency: Optional[str] = None
    r"""The currency of the invoice"""

    business_unit: Annotated[
        Optional[BusinessUnit], pydantic.Field(alias="businessUnit")
    ] = None
    r"""Business Unit (invoice recipient) details"""

    vendor: Optional[Vendor] = None
    r"""Vendor details"""

    delivery_date: Annotated[Optional[date], pydantic.Field(alias="deliveryDate")] = (
        None
    )
    r"""The date the goods were delivered or services performed"""

    invoice_data: Annotated[
        Optional[InvoiceData], pydantic.Field(alias="invoiceData")
    ] = None

    due_date: Annotated[Optional[date], pydantic.Field(alias="dueDate")] = None
    r"""The date by which the invoice should be paid"""

    reversed_charge: Annotated[
        Optional[bool], pydantic.Field(alias="reversedCharge")
    ] = None
    r"""Indicates that a reverse charge is applied"""

    taxes: Optional[InvoiceFieldsTaxes] = None
    r"""Tax information"""

    invoice_type: Annotated[
        Optional[InvoiceType], pydantic.Field(alias="invoiceType")
    ] = None
    r"""The type of invoice document"""

    purchase_order: Annotated[
        Optional[List[InvoiceFieldsPurchaseOrder]],
        pydantic.Field(alias="purchaseOrder"),
    ] = None
    r"""Purchase order details"""

    line_items: Annotated[
        Optional[List[LineItems]], pydantic.Field(alias="lineItems")
    ] = None
    r"""List of line items in the invoice"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class Boxes1520TypedDict(TypedDict):
    box15_employers_state_id_number: NotRequired[str]
    r"""Employer's state ID number"""
    box15_state: NotRequired[str]
    r"""State abbreviation"""
    box16_state_wages_tips: NotRequired[float]
    r"""State wages, tips, etc."""
    box17_state_income_tax: NotRequired[float]
    r"""State income tax"""
    box18_local_wages_tips: NotRequired[float]
    r"""Local wages, tips, etc."""
    box19_local_income_tax: NotRequired[float]
    r"""Local income tax"""
    box20_locality_name: NotRequired[str]
    r"""Locality name"""


class Boxes1520(BaseModel):
    box15_employers_state_id_number: Annotated[
        Optional[str], pydantic.Field(alias="box15EmployersStateIDNumber")
    ] = None
    r"""Employer's state ID number"""

    box15_state: Annotated[Optional[str], pydantic.Field(alias="box15State")] = None
    r"""State abbreviation"""

    box16_state_wages_tips: Annotated[
        Optional[float], pydantic.Field(alias="box16StateWagesTips")
    ] = None
    r"""State wages, tips, etc."""

    box17_state_income_tax: Annotated[
        Optional[float], pydantic.Field(alias="box17StateIncomeTax")
    ] = None
    r"""State income tax"""

    box18_local_wages_tips: Annotated[
        Optional[float], pydantic.Field(alias="box18LocalWagesTips")
    ] = None
    r"""Local wages, tips, etc."""

    box19_local_income_tax: Annotated[
        Optional[float], pydantic.Field(alias="box19LocalIncomeTax")
    ] = None
    r"""Local income tax"""

    box20_locality_name: Annotated[
        Optional[str], pydantic.Field(alias="box20LocalityName")
    ] = None
    r"""Locality name"""


class USFormW2FieldsTypedDict(TypedDict):
    r"""Fields extracted from a US Form W-2"""

    year: NotRequired[str]
    r"""The filing year"""
    box_a_employees_social_security_number: NotRequired[str]
    r"""The employee's social security number"""
    box_b_employer_identification_number_ein: NotRequired[str]
    r"""The employer's identification number"""
    box_c_employers_name: NotRequired[str]
    r"""The employer's name"""
    box_c_employers_address: NotRequired[str]
    r"""The employer's address"""
    box_d_control_number: NotRequired[str]
    r"""The control number"""
    box_e_employees_name: NotRequired[str]
    r"""The employee's first name, initial, and last name"""
    box_f_employees_address: NotRequired[str]
    r"""The employee's address"""
    box1_wages_tips_other_compensation: NotRequired[float]
    r"""Wages, tips, and other compensation"""
    box2_federal_income_tax_withheld: NotRequired[float]
    r"""Federal income tax withheld"""
    box3_social_security_wages: NotRequired[float]
    r"""Social security wages"""
    box4_social_security_tax_withheld: NotRequired[float]
    r"""Social security tax withheld"""
    box5_medicare_wages_and_tips: NotRequired[float]
    r"""Medicare wages and tips"""
    box6_medicare_tax_withheld: NotRequired[float]
    r"""Medicare tax withheld"""
    box7_social_security_tips: NotRequired[float]
    r"""Social security tips"""
    box8_allocated_tips: NotRequired[float]
    r"""Allocated tips"""
    box9_verification_code: NotRequired[str]
    r"""Verification code"""
    box10_dependent_care_benefits: NotRequired[float]
    r"""Dependent care benefits"""
    box11_nonqualified_plans: NotRequired[float]
    r"""Nonqualified plans"""
    box12a_code: NotRequired[str]
    r"""Single or double letter code"""
    box12a_amount: NotRequired[float]
    r"""Dollar amount"""
    box12b_code: NotRequired[str]
    r"""Single or double letter code"""
    box12b_amount: NotRequired[float]
    r"""Dollar amount"""
    box12c_code: NotRequired[str]
    r"""Single or double letter code"""
    box12c_amount: NotRequired[float]
    r"""Dollar amount"""
    box12d_code: NotRequired[str]
    r"""Single or double letter code"""
    box12d_amount: NotRequired[float]
    r"""Dollar amount"""
    box13_statutory_employee: NotRequired[bool]
    r"""Indicates whether the employee works full-time or part-time"""
    box13_retirement_plan: NotRequired[bool]
    r"""Indicates whether the employee participates in a pension or retirement plan"""
    box13_third_party_sick_pay: NotRequired[bool]
    r"""Indicates whether the employer is a third-party sick pay payer"""
    box14_other: NotRequired[str]
    r"""Additional information"""
    boxes1520: NotRequired[List[Boxes1520TypedDict]]


class USFormW2Fields(BaseModel):
    r"""Fields extracted from a US Form W-2"""

    year: Optional[str] = None
    r"""The filing year"""

    box_a_employees_social_security_number: Annotated[
        Optional[str], pydantic.Field(alias="boxAEmployeesSocialSecurityNumber")
    ] = None
    r"""The employee's social security number"""

    box_b_employer_identification_number_ein: Annotated[
        Optional[str], pydantic.Field(alias="boxBEmployerIdentificationNumberEin")
    ] = None
    r"""The employer's identification number"""

    box_c_employers_name: Annotated[
        Optional[str], pydantic.Field(alias="boxCEmployersName")
    ] = None
    r"""The employer's name"""

    box_c_employers_address: Annotated[
        Optional[str], pydantic.Field(alias="boxCEmployersAddress")
    ] = None
    r"""The employer's address"""

    box_d_control_number: Annotated[
        Optional[str], pydantic.Field(alias="boxDControlNumber")
    ] = None
    r"""The control number"""

    box_e_employees_name: Annotated[
        Optional[str], pydantic.Field(alias="boxEEmployeesName")
    ] = None
    r"""The employee's first name, initial, and last name"""

    box_f_employees_address: Annotated[
        Optional[str], pydantic.Field(alias="boxFEmployeesAddress")
    ] = None
    r"""The employee's address"""

    box1_wages_tips_other_compensation: Annotated[
        Optional[float], pydantic.Field(alias="box1WagesTipsOtherCompensation")
    ] = None
    r"""Wages, tips, and other compensation"""

    box2_federal_income_tax_withheld: Annotated[
        Optional[float], pydantic.Field(alias="box2FederalIncomeTaxWithheld")
    ] = None
    r"""Federal income tax withheld"""

    box3_social_security_wages: Annotated[
        Optional[float], pydantic.Field(alias="box3SocialSecurityWages")
    ] = None
    r"""Social security wages"""

    box4_social_security_tax_withheld: Annotated[
        Optional[float], pydantic.Field(alias="box4SocialSecurityTaxWithheld")
    ] = None
    r"""Social security tax withheld"""

    box5_medicare_wages_and_tips: Annotated[
        Optional[float], pydantic.Field(alias="box5MedicareWagesAndTips")
    ] = None
    r"""Medicare wages and tips"""

    box6_medicare_tax_withheld: Annotated[
        Optional[float], pydantic.Field(alias="box6MedicareTaxWithheld")
    ] = None
    r"""Medicare tax withheld"""

    box7_social_security_tips: Annotated[
        Optional[float], pydantic.Field(alias="box7SocialSecurityTips")
    ] = None
    r"""Social security tips"""

    box8_allocated_tips: Annotated[
        Optional[float], pydantic.Field(alias="box8AllocatedTips")
    ] = None
    r"""Allocated tips"""

    box9_verification_code: Annotated[
        Optional[str], pydantic.Field(alias="box9VerificationCode")
    ] = None
    r"""Verification code"""

    box10_dependent_care_benefits: Annotated[
        Optional[float], pydantic.Field(alias="box10DependentCareBenefits")
    ] = None
    r"""Dependent care benefits"""

    box11_nonqualified_plans: Annotated[
        Optional[float], pydantic.Field(alias="box11NonqualifiedPlans")
    ] = None
    r"""Nonqualified plans"""

    box12a_code: Annotated[Optional[str], pydantic.Field(alias="box12aCode")] = None
    r"""Single or double letter code"""

    box12a_amount: Annotated[Optional[float], pydantic.Field(alias="box12aAmount")] = (
        None
    )
    r"""Dollar amount"""

    box12b_code: Annotated[Optional[str], pydantic.Field(alias="box12bCode")] = None
    r"""Single or double letter code"""

    box12b_amount: Annotated[Optional[float], pydantic.Field(alias="box12bAmount")] = (
        None
    )
    r"""Dollar amount"""

    box12c_code: Annotated[Optional[str], pydantic.Field(alias="box12cCode")] = None
    r"""Single or double letter code"""

    box12c_amount: Annotated[Optional[float], pydantic.Field(alias="box12cAmount")] = (
        None
    )
    r"""Dollar amount"""

    box12d_code: Annotated[Optional[str], pydantic.Field(alias="box12dCode")] = None
    r"""Single or double letter code"""

    box12d_amount: Annotated[Optional[float], pydantic.Field(alias="box12dAmount")] = (
        None
    )
    r"""Dollar amount"""

    box13_statutory_employee: Annotated[
        Optional[bool], pydantic.Field(alias="box13StatutoryEmployee")
    ] = None
    r"""Indicates whether the employee works full-time or part-time"""

    box13_retirement_plan: Annotated[
        Optional[bool], pydantic.Field(alias="box13RetirementPlan")
    ] = None
    r"""Indicates whether the employee participates in a pension or retirement plan"""

    box13_third_party_sick_pay: Annotated[
        Optional[bool], pydantic.Field(alias="box13ThirdPartySickPay")
    ] = None
    r"""Indicates whether the employer is a third-party sick pay payer"""

    box14_other: Annotated[Optional[str], pydantic.Field(alias="box14Other")] = None
    r"""Additional information"""

    boxes1520: Optional[List[Boxes1520]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .certificateoforigin import CertificateOfOrigin, CertificateOfOriginTypedDict
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from abbyy_document_ai.types import BaseModel
from abbyy_document_ai.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetExtractedCertificateOfOriginFieldsRequestTypedDict(TypedDict):
    document_id: str
    r"""The id of the document"""


class GetExtractedCertificateOfOriginFieldsRequest(BaseModel):
    document_id: Annotated[
        str,
        pydantic.Field(alias="documentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The id of the document"""


class GetExtractedCertificateOfOriginFieldsResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    certificate_of_origin: NotRequired[CertificateOfOriginTypedDict]
    r"""Extracted Certificate Of Origin Data Response"""


class GetExtractedCertificateOfOriginFieldsResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    certificate_of_origin: Optional[CertificateOfOrigin] = None
    r"""Extracted Certificate Of Origin Data Response"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ExpenseTypeTypedDict(TypedDict):
    r"""The type of the expense"""

    airfare: NotRequired[bool]
    r"""Receipts for booked flights"""
    car_parking: NotRequired[bool]
    r"""Receipts from parking meters"""
    car_rental: NotRequired[bool]
    r"""Receipts from car rental services"""
    gasoline_station: NotRequired[bool]
    r"""Receipts from gas stations"""
    general_retail: NotRequired[bool]
    r"""Receipts from stores, supermarkets, etc."""
    hotel: NotRequired[bool]
    r"""Receipts from hotels"""
    other: NotRequired[bool]
    r"""Other types of receipts"""
    restaurant: NotRequired[bool]
    r"""Restaurant bills"""
    taxi: NotRequired[bool]
    r"""Taxi receipts"""
    toll_road: NotRequired[bool]
    r"""Toll receipts"""
    transport: NotRequired[bool]
    r"""Receipts for public transportation fares"""


class ExpenseType(BaseModel):
    r"""The type of the expense"""

    airfare: Optional[bool] = None
    r"""Receipts for booked flights"""

    car_parking: Annotated[Optional[bool], pydantic.Field(alias="carParking")] = None
    r"""Receipts from parking meters"""

    car_rental: Annotated[Optional[bool], pydantic.Field(alias="carRental")] = None
    r"""Receipts from car rental services"""

    gasoline_station: Annotated[
        Optional[bool], pydantic.Field(alias="gasolineStation")
    ] = None
    r"""Receipts from gas stations"""

    general_retail: Annotated[Optional[bool], pydantic.Field(alias="generalRetail")] = (
        None
    )
    r"""Receipts from stores, supermarkets, etc."""

    hotel: Optional[bool] = None
    r"""Receipts from hotels"""

    other: Optional[bool] = None
    r"""Other types of receipts"""

    restaurant: Optional[bool] = None
    r"""Restaurant bills"""

    taxi: Optional[bool] = None
    r"""Taxi receipts"""

    toll_road: Annotated[Optional[bool], pydantic.Field(alias="tollRoad")] = None
    r"""Toll receipts"""

    transport: Optional[bool] = None
    r"""Receipts for public transportation fares"""


class TaxesTypedDict(TypedDict):
    r"""Tax details"""

    tax_amount: NotRequired[float]
    r"""The tax amount"""
    tax_rate: NotRequired[float]
    r"""The tax rate"""


class Taxes(BaseModel):
    r"""Tax details"""

    tax_amount: Annotated[Optional[float], pydantic.Field(alias="taxAmount")] = None
    r"""The tax amount"""

    tax_rate: Annotated[Optional[float], pydantic.Field(alias="taxRate")] = None
    r"""The tax rate"""


class ReceiptLineItemTypedDict(TypedDict):
    r"""A line item representing a purchased product or service in a receipt"""

    description: NotRequired[str]
    r"""The name of the purchased product or service"""
    sku: NotRequired[str]
    r"""The stock-keeping unit identifier of the product (if present)"""
    quantity: NotRequired[float]
    r"""The quantity of the product purchased"""
    price: NotRequired[float]
    r"""The price per unit"""
    amount: NotRequired[float]
    r"""The total sum in the line item"""


class ReceiptLineItem(BaseModel):
    r"""A line item representing a purchased product or service in a receipt"""

    description: Optional[str] = None
    r"""The name of the purchased product or service"""

    sku: Optional[str] = None
    r"""The stock-keeping unit identifier of the product (if present)"""

    quantity: Optional[float] = None
    r"""The quantity of the product purchased"""

    price: Optional[float] = None
    r"""The price per unit"""

    amount: Optional[float] = None
    r"""The total sum in the line item"""


class ReceiptFieldsTypedDict(TypedDict):
    r"""Fields extracted from a receipt"""

    vendor: NotRequired[str]
    r"""The name of the organization that issued the receipt"""
    address: NotRequired[str]
    r"""The address of the organization that issued the receipt"""
    city: NotRequired[str]
    r"""The city where the payment was made"""
    country: NotRequired[str]
    r"""The country where the payment was made"""
    date_: NotRequired[date]
    r"""The date when the payment was made"""
    currency: NotRequired[str]
    r"""The currency of the payment"""
    total: NotRequired[float]
    r"""The total amount of the receipt"""
    phone: NotRequired[str]
    r"""The phone number of the organization that issued the receipt"""
    expense_type: NotRequired[ExpenseTypeTypedDict]
    r"""The type of the expense"""
    payment_method: NotRequired[str]
    r"""Payment method. Possible values: Card, Cash, Transfer, Mixed, Undefined"""
    card_type: NotRequired[str]
    r"""The payment processing network of the card used for payment. Possible values: Mastercard, VISA, AmericanExpress, NationalCard, Undefined"""
    card_number: NotRequired[str]
    r"""The number of the card used for payment. The number may be partially masked by replacing some digits with the X character"""
    tip: NotRequired[float]
    r"""The tip amount"""
    taxes: NotRequired[List[TaxesTypedDict]]
    r"""Tax details. No details will be shown if the Tax Rate and Tax Amount fields are empty. If multiple taxes have been detected, they will be displayed as multiple lines"""
    tax_total: NotRequired[float]
    r"""The total amount of tax levied on the purchase"""
    line_items: NotRequired[List[ReceiptLineItemTypedDict]]
    r"""The list of the purchased goods or services"""


class ReceiptFields(BaseModel):
    r"""Fields extracted from a receipt"""

    vendor: Optional[str] = None
    r"""The name of the organization that issued the receipt"""

    address: Optional[str] = None
    r"""The address of the organization that issued the receipt"""

    city: Optional[str] = None
    r"""The city where the payment was made"""

    country: Optional[str] = None
    r"""The country where the payment was made"""

    date_: Annotated[Optional[date], pydantic.Field(alias="date")] = None
    r"""The date when the payment was made"""

    currency: Optional[str] = None
    r"""The currency of the payment"""

    total: Optional[float] = None
    r"""The total amount of the receipt"""

    phone: Optional[str] = None
    r"""The phone number of the organization that issued the receipt"""

    expense_type: Annotated[
        Optional[ExpenseType], pydantic.Field(alias="expenseType")
    ] = None
    r"""The type of the expense"""

    payment_method: Annotated[Optional[str], pydantic.Field(alias="paymentMethod")] = (
        None
    )
    r"""Payment method. Possible values: Card, Cash, Transfer, Mixed, Undefined"""

    card_type: Annotated[Optional[str], pydantic.Field(alias="cardType")] = None
    r"""The payment processing network of the card used for payment. Possible values: Mastercard, VISA, AmericanExpress, NationalCard, Undefined"""

    card_number: Annotated[Optional[str], pydantic.Field(alias="cardNumber")] = None
    r"""The number of the card used for payment. The number may be partially masked by replacing some digits with the X character"""

    tip: Optional[float] = None
    r"""The tip amount"""

    taxes: Optional[List[Taxes]] = None
    r"""Tax details. No details will be shown if the Tax Rate and Tax Amount fields are empty. If multiple taxes have been detected, they will be displayed as multiple lines"""

    tax_total: Annotated[Optional[float], pydantic.Field(alias="taxTotal")] = None
    r"""The total amount of tax levied on the purchase"""

    line_items: Annotated[
        Optional[List[ReceiptLineItem]], pydantic.Field(alias="lineItems")
    ] = None
    r"""The list of the purchased goods or services"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class BrokerTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the broker"""
    address: NotRequired[str]
    r"""The address of the broker"""
    phone_number: NotRequired[str]
    r"""The phone number of the broker"""


class Broker(BaseModel):
    name: Optional[str] = None
    r"""The name of the broker"""

    address: Optional[str] = None
    r"""The address of the broker"""

    phone_number: Annotated[Optional[str], pydantic.Field(alias="phoneNumber")] = None
    r"""The phone number of the broker"""


class AdvisorTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the advisor"""
    phone_number: NotRequired[str]
    r"""The phone number of the advisor"""
    address: NotRequired[str]
    r"""The address of the advisor"""


class Advisor(BaseModel):
    name: Optional[str] = None
    r"""The name of the advisor"""

    phone_number: Annotated[Optional[str], pydantic.Field(alias="phoneNumber")] = None
    r"""The phone number of the advisor"""

    address: Optional[str] = None
    r"""The address of the advisor"""


class ClientTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the client"""
    address: NotRequired[str]
    r"""The address of the client"""
    phone_number: NotRequired[str]
    r"""The phone number of the client"""


class Client(BaseModel):
    name: Optional[str] = None
    r"""The name of the client"""

    address: Optional[str] = None
    r"""The address of the client"""

    phone_number: Annotated[Optional[str], pydantic.Field(alias="phoneNumber")] = None
    r"""The phone number of the client"""


class HoldingsLevelTypedDict(TypedDict):
    account_type: NotRequired[str]
    r"""The type of account in which the investor holds the securities listed on the statement"""
    asset_class: NotRequired[str]
    r"""The classification of the investments held in the brokerage account according to their asset class"""
    description: NotRequired[str]
    r"""A detailed description of each investment held in the brokerage account"""
    symbol: NotRequired[str]
    r"""The unique ticker symbol assigned to each investment held in the brokerage account"""
    cusip: NotRequired[str]
    r"""The unique identifier assigned to each security registered with the Committee on Uniform Securities Identification Procedures (CUSIP)"""
    quantity: NotRequired[float]
    r"""The number of shares or units of a security that are held in the investor's brokerage account"""
    price: NotRequired[float]
    r"""The price per share or unit of a security at the time it was acquired by the investor"""
    price_as_of_date: NotRequired[date]
    r"""The date on which the price per share or unit of a security was last updated or determined by the broker"""
    currency: NotRequired[str]
    r"""The currency in which the security is denominated or traded"""
    market_value: NotRequired[float]
    r"""The current market value of an investor's holdings of a particular security"""
    prior_market_value: NotRequired[float]
    r"""The market value of an investor's holdings of a particular security as of the previous statement date"""
    cost_basis: NotRequired[float]
    r"""The total amount an investor has paid to acquire their current holdings of a particular security"""
    accrued_value: NotRequired[float]
    r"""The value of the investor's accrued earnings on the security"""
    estimated_income: NotRequired[float]
    r"""The estimated income that includes interest, dividends, and other income that the investor is expected to receive from their holdings"""
    estimated_yield: NotRequired[float]
    r"""The estimated yield that an investor can expect to earn from their holdings of a particular security over a given period of time"""
    current_yield: NotRequired[float]
    r"""The actual yield an investor is currently earning from their holdings of a particular security"""


class HoldingsLevel(BaseModel):
    account_type: Annotated[Optional[str], pydantic.Field(alias="accountType")] = None
    r"""The type of account in which the investor holds the securities listed on the statement"""

    asset_class: Annotated[Optional[str], pydantic.Field(alias="assetClass")] = None
    r"""The classification of the investments held in the brokerage account according to their asset class"""

    description: Optional[str] = None
    r"""A detailed description of each investment held in the brokerage account"""

    symbol: Optional[str] = None
    r"""The unique ticker symbol assigned to each investment held in the brokerage account"""

    cusip: Optional[str] = None
    r"""The unique identifier assigned to each security registered with the Committee on Uniform Securities Identification Procedures (CUSIP)"""

    quantity: Optional[float] = None
    r"""The number of shares or units of a security that are held in the investor's brokerage account"""

    price: Optional[float] = None
    r"""The price per share or unit of a security at the time it was acquired by the investor"""

    price_as_of_date: Annotated[
        Optional[date], pydantic.Field(alias="priceAsOfDate")
    ] = None
    r"""The date on which the price per share or unit of a security was last updated or determined by the broker"""

    currency: Optional[str] = None
    r"""The currency in which the security is denominated or traded"""

    market_value: Annotated[Optional[float], pydantic.Field(alias="marketValue")] = None
    r"""The current market value of an investor's holdings of a particular security"""

    prior_market_value: Annotated[
        Optional[float], pydantic.Field(alias="priorMarketValue")
    ] = None
    r"""The market value of an investor's holdings of a particular security as of the previous statement date"""

    cost_basis: Annotated[Optional[float], pydantic.Field(alias="costBasis")] = None
    r"""The total amount an investor has paid to acquire their current holdings of a particular security"""

    accrued_value: Annotated[Optional[float], pydantic.Field(alias="accruedValue")] = (
        None
    )
    r"""The value of the investor's accrued earnings on the security"""

    estimated_income: Annotated[
        Optional[float], pydantic.Field(alias="estimatedIncome")
    ] = None
    r"""The estimated income that includes interest, dividends, and other income that the investor is expected to receive from their holdings"""

    estimated_yield: Annotated[
        Optional[float], pydantic.Field(alias="estimatedYield")
    ] = None
    r"""The estimated yield that an investor can expect to earn from their holdings of a particular security over a given period of time"""

    current_yield: Annotated[Optional[float], pydantic.Field(alias="currentYield")] = (
        None
    )
    r"""The actual yield an investor is currently earning from their holdings of a particular security"""


class TransactionsTypedDict(TypedDict):
    trade_date: NotRequired[str]
    r"""The date on which a particular trade was executed"""
    settlement_date: NotRequired[str]
    r"""The date on which the settlement process is complete"""
    account_type: NotRequired[str]
    r"""The type of account associated with a particular trade transaction"""
    transaction_type_level1: NotRequired[str]
    r"""The broad category or type of a particular trade transaction"""
    transaction_type_level2: NotRequired[str]
    r"""Additional detail about the specific type of trade transaction that occurred"""
    transaction_type: NotRequired[str]
    r"""The specific type of transaction that occurred in an investor's account during the statement period"""
    description: NotRequired[str]
    r"""Additional details about the specific transaction that occurred in an investor's account"""
    symbol: NotRequired[str]
    r"""The ticker symbol of the security that was involved in a particular transaction"""
    quantity: NotRequired[float]
    r"""The number of shares, units, or contracts involved in a particular transaction"""
    price: NotRequired[float]
    r"""The price at which a security was bought or sold during a particular transaction"""
    currency: NotRequired[str]
    r"""The currency in which a particular transaction was executed"""
    amount: NotRequired[float]
    r"""The total amount associated with a particular transaction"""
    taxable_amount: NotRequired[float]
    r"""The amount of taxable income associated with specific transactions"""
    non_taxable_amount: NotRequired[float]
    r"""The amount of income or proceeds from tax-exempt transactions"""
    pending_status: NotRequired[str]
    r"""The current status of a transaction that is pending or not yet completed"""


class Transactions(BaseModel):
    trade_date: Annotated[Optional[str], pydantic.Field(alias="tradeDate")] = None
    r"""The date on which a particular trade was executed"""

    settlement_date: Annotated[
        Optional[str], pydantic.Field(alias="settlementDate")
    ] = None
    r"""The date on which the settlement process is complete"""

    account_type: Annotated[Optional[str], pydantic.Field(alias="accountType")] = None
    r"""The type of account associated with a particular trade transaction"""

    transaction_type_level1: Annotated[
        Optional[str], pydantic.Field(alias="transactionTypeLevel1")
    ] = None
    r"""The broad category or type of a particular trade transaction"""

    transaction_type_level2: Annotated[
        Optional[str], pydantic.Field(alias="transactionTypeLevel2")
    ] = None
    r"""Additional detail about the specific type of trade transaction that occurred"""

    transaction_type: Annotated[
        Optional[str], pydantic.Field(alias="transactionType")
    ] = None
    r"""The specific type of transaction that occurred in an investor's account during the statement period"""

    description: Optional[str] = None
    r"""Additional details about the specific transaction that occurred in an investor's account"""

    symbol: Optional[str] = None
    r"""The ticker symbol of the security that was involved in a particular transaction"""

    quantity: Optional[float] = None
    r"""The number of shares, units, or contracts involved in a particular transaction"""

    price: Optional[float] = None
    r"""The price at which a security was bought or sold during a particular transaction"""

    currency: Optional[str] = None
    r"""The currency in which a particular transaction was executed"""

    amount: Optional[float] = None
    r"""The total amount associated with a particular transaction"""

    taxable_amount: Annotated[
        Optional[float], pydantic.Field(alias="taxableAmount")
    ] = None
    r"""The amount of taxable income associated with specific transactions"""

    non_taxable_amount: Annotated[
        Optional[float], pydantic.Field(alias="nonTaxableAmount")
    ] = None
    r"""The amount of income or proceeds from tax-exempt transactions"""

    pending_status: Annotated[Optional[str], pydantic.Field(alias="pendingStatus")] = (
        None
    )
    r"""The current status of a transaction that is pending or not yet completed"""


class BrokerageStatementFieldsTypedDict(TypedDict):
    r"""Fields extracted from a brokerage statement"""

    account_number: NotRequired[str]
    r"""The unique number assigned to an investment account by the broker or investment firm"""
    broker: NotRequired[BrokerTypedDict]
    advisor: NotRequired[List[AdvisorTypedDict]]
    client: NotRequired[ClientTypedDict]
    statement_start_date: NotRequired[date]
    r"""The beginning of the statement period for which the statement was generated"""
    statement_end_date: NotRequired[date]
    r"""The end of the statement period for which the statement was generated"""
    statement_period: NotRequired[str]
    r"""The period between the statement start date and the statement end date"""
    total_portfolio_value: NotRequired[float]
    r"""The total value of an investor's investment holdings within the account as of the statement date"""
    base_currency: NotRequired[str]
    r"""The currency that is used to calculate the value of the account's holdings and any gains or losses"""
    holdings_level: NotRequired[List[HoldingsLevelTypedDict]]
    transactions: NotRequired[List[TransactionsTypedDict]]


class BrokerageStatementFields(BaseModel):
    r"""Fields extracted from a brokerage statement"""

    account_number: Annotated[Optional[str], pydantic.Field(alias="accountNumber")] = (
        None
    )
    r"""The unique number assigned to an investment account by the broker or investment firm"""

    broker: Optional[Broker] = None

    advisor: Optional[List[Advisor]] = None

    client: Optional[Client] = None

    statement_start_date: Annotated[
        Optional[date], pydantic.Field(alias="statementStartDate")
    ] = None
    r"""The beginning of the statement period for which the statement was generated"""

    statement_end_date: Annotated[
        Optional[date], pydantic.Field(alias="statementEndDate")
    ] = None
    r"""The end of the statement period for which the statement was generated"""

    statement_period: Annotated[
        Optional[str], pydantic.Field(alias="statementPeriod")
    ] = None
    r"""The period between the statement start date and the statement end date"""

    total_portfolio_value: Annotated[
        Optional[float], pydantic.Field(alias="totalPortfolioValue")
    ] = None
    r"""The total value of an investor's investment holdings within the account as of the statement date"""

    base_currency: Annotated[Optional[str], pydantic.Field(alias="baseCurrency")] = None
    r"""The currency that is used to calculate the value of the account's holdings and any gains or losses"""

    holdings_level: Annotated[
        Optional[List[HoldingsLevel]], pydantic.Field(alias="holdingsLevel")
    ] = None

    transactions: Optional[List[Transactions]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class BuyerTypedDict(TypedDict):
    r"""Buyer details"""

    name: NotRequired[str]
    r"""The name of the buyer"""
    tax_id: NotRequired[str]
    r"""The tax identification number of the buyer"""
    buyer_id: NotRequired[str]
    r"""The buyer id"""
    iban: NotRequired[str]
    r"""The buyer's international bank account number"""
    bank_account: NotRequired[str]
    r"""The bank account number of the buyer"""
    bank_code: NotRequired[str]
    r"""The bank code of the buyer"""
    address: NotRequired[str]
    r"""The address of the buyer"""
    country: NotRequired[str]
    r"""The country of the buyer"""
    state: NotRequired[str]
    r"""The state part of the buyer's address"""
    state_or_province: NotRequired[str]
    r"""The state or province part of the buyer's address"""
    city: NotRequired[str]
    r"""The city part of the buyer's address"""
    street: NotRequired[str]
    r"""The street part of the buyer's address"""
    postal_code: NotRequired[str]
    r"""The postal code part of the buyer's address"""
    zip_code: NotRequired[str]
    r"""The ZIP code part of the buyer's address"""


class Buyer(BaseModel):
    r"""Buyer details"""

    name: Optional[str] = None
    r"""The name of the buyer"""

    tax_id: Annotated[Optional[str], pydantic.Field(alias="taxId")] = None
    r"""The tax identification number of the buyer"""

    buyer_id: Annotated[Optional[str], pydantic.Field(alias="buyerId")] = None
    r"""The buyer id"""

    iban: Optional[str] = None
    r"""The buyer's international bank account number"""

    bank_account: Annotated[Optional[str], pydantic.Field(alias="bankAccount")] = None
    r"""The bank account number of the buyer"""

    bank_code: Annotated[Optional[str], pydantic.Field(alias="bankCode")] = None
    r"""The bank code of the buyer"""

    address: Optional[str] = None
    r"""The address of the buyer"""

    country: Optional[str] = None
    r"""The country of the buyer"""

    state: Optional[str] = None
    r"""The state part of the buyer's address"""

    state_or_province: Annotated[
        Optional[str], pydantic.Field(alias="stateOrProvince")
    ] = None
    r"""The state or province part of the buyer's address"""

    city: Optional[str] = None
    r"""The city part of the buyer's address"""

    street: Optional[str] = None
    r"""The street part of the buyer's address"""

    postal_code: Annotated[Optional[str], pydantic.Field(alias="postalCode")] = None
    r"""The postal code part of the buyer's address"""

    zip_code: Annotated[Optional[str], pydantic.Field(alias="zipCode")] = None
    r"""The ZIP code part of the buyer's address"""


class SupplierTypedDict(TypedDict):
    r"""Supplier details"""

    name: NotRequired[str]
    r"""The name of the supplier"""
    tax_id: NotRequired[str]
    r"""The tax identification number of the supplier"""
    supplier_id: NotRequired[str]
    r"""The supplier ID"""
    address: NotRequired[str]
    r"""The address of the supplier"""
    country: NotRequired[str]
    r"""The country of the supplier"""
    state: NotRequired[str]
    r"""The state part of the supplier's address"""
    state_or_province: NotRequired[str]
    r"""The state or province part of the supplier's address"""
    city: NotRequired[str]
    r"""The city part of the supplier's address"""
    street: NotRequired[str]
    r"""The street part of the supplier's address"""
    postal_code: NotRequired[str]
    r"""The postal code part of the supplier's address"""
    zip_code: NotRequired[str]
    r"""The ZIP code part of the supplier's address"""


class Supplier(BaseModel):
    r"""Supplier details"""

    name: Optional[str] = None
    r"""The name of the supplier"""

    tax_id: Annotated[Optional[str], pydantic.Field(alias="taxId")] = None
    r"""The tax identification number of the supplier"""

    supplier_id: Annotated[Optional[str], pydantic.Field(alias="supplierId")] = None
    r"""The supplier ID"""

    address: Optional[str] = None
    r"""The address of the supplier"""

    country: Optional[str] = None
    r"""The country of the supplier"""

    state: Optional[str] = None
    r"""The state part of the supplier's address"""

    state_or_province: Annotated[
        Optional[str], pydantic.Field(alias="stateOrProvince")
    ] = None
    r"""The state or province part of the supplier's address"""

    city: Optional[str] = None
    r"""The city part of the supplier's address"""

    street: Optional[str] = None
    r"""The street part of the supplier's address"""

    postal_code: Annotated[Optional[str], pydantic.Field(alias="postalCode")] = None
    r"""The postal code part of the supplier's address"""

    zip_code: Annotated[Optional[str], pydantic.Field(alias="zipCode")] = None
    r"""The ZIP code part of the supplier's address"""


class ShipToTypedDict(TypedDict):
    r"""The recipient of the goods or services"""

    name: NotRequired[str]
    r"""The name of the recipient of the goods or services"""
    address: NotRequired[str]
    r"""The address where the goods must be delivered"""


class ShipTo(BaseModel):
    r"""The recipient of the goods or services"""

    name: Optional[str] = None
    r"""The name of the recipient of the goods or services"""

    address: Optional[str] = None
    r"""The address where the goods must be delivered"""


class BillToTypedDict(TypedDict):
    r"""The recipient of the invoice"""

    name: NotRequired[str]
    r"""The name of the recipient of the invoice"""
    address: NotRequired[str]
    r"""The address where the invoice must be sent"""


class BillTo(BaseModel):
    r"""The recipient of the invoice"""

    name: Optional[str] = None
    r"""The name of the recipient of the invoice"""

    address: Optional[str] = None
    r"""The address where the invoice must be sent"""


class PurchaseOrderFieldsLineItemsTypedDict(TypedDict):
    r"""Line item details"""

    position: NotRequired[float]
    r"""The number of the line item in the list"""
    article_number_buyer: NotRequired[str]
    r"""The article number of the goods in the buyer's database"""
    article_number_supplier: NotRequired[str]
    r"""The article number of the goods in the supplier's database"""
    description: NotRequired[str]
    r"""A description of the goods or services"""
    quantity: NotRequired[float]
    r"""The number of units ordered"""
    unit_of_measurement: NotRequired[str]
    r"""The unit of measurement used for the goods"""
    unit_price: NotRequired[float]
    r"""The price of one item of goods"""
    discount: NotRequired[float]
    r"""The applicable discount in the currency of the purchase order"""
    total_price: NotRequired[float]
    r"""The price of the line item including tax"""
    currency: NotRequired[str]
    r"""The currency of the line item"""
    delivery_date: NotRequired[date]
    r"""The delivery date of the goods in the line item"""


class PurchaseOrderFieldsLineItems(BaseModel):
    r"""Line item details"""

    position: Optional[float] = None
    r"""The number of the line item in the list"""

    article_number_buyer: Annotated[
        Optional[str], pydantic.Field(alias="articleNumberBuyer")
    ] = None
    r"""The article number of the goods in the buyer's database"""

    article_number_supplier: Annotated[
        Optional[str], pydantic.Field(alias="articleNumberSupplier")
    ] = None
    r"""The article number of the goods in the supplier's database"""

    description: Optional[str] = None
    r"""A description of the goods or services"""

    quantity: Optional[float] = None
    r"""The number of units ordered"""

    unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="unitOfMeasurement")
    ] = None
    r"""The unit of measurement used for the goods"""

    unit_price: Annotated[Optional[float], pydantic.Field(alias="unitPrice")] = None
    r"""The price of one item of goods"""

    discount: Optional[float] = None
    r"""The applicable discount in the currency of the purchase order"""

    total_price: Annotated[Optional[float], pydantic.Field(alias="totalPrice")] = None
    r"""The price of the line item including tax"""

    currency: Optional[str] = None
    r"""The currency of the line item"""

    delivery_date: Annotated[Optional[date], pydantic.Field(alias="deliveryDate")] = (
        None
    )
    r"""The delivery date of the goods in the line item"""


class PurchaseOrderFieldsTaxesTypedDict(TypedDict):
    r"""Tax information"""

    total_net_amount: NotRequired[float]
    r"""The total cost of goods without tax"""
    total_tax_amount: NotRequired[float]
    r"""The total tax amount"""


class PurchaseOrderFieldsTaxes(BaseModel):
    r"""Tax information"""

    total_net_amount: Annotated[
        Optional[float], pydantic.Field(alias="totalNetAmount")
    ] = None
    r"""The total cost of goods without tax"""

    total_tax_amount: Annotated[
        Optional[float], pydantic.Field(alias="totalTaxAmount")
    ] = None
    r"""The total tax amount"""


class PurchaseOrderFieldsTypedDict(TypedDict):
    r"""Fields extracted from a purchase order"""

    order_number: NotRequired[str]
    r"""The number of the purchase order"""
    order_date: NotRequired[date]
    r"""The date when the purchase order was created"""
    total: NotRequired[float]
    r"""The total amount of the purchase order"""
    currency: NotRequired[str]
    r"""The currency of the total amount. If no total amount is indicated, this field will be empty."""
    buyer: NotRequired[BuyerTypedDict]
    r"""Buyer details"""
    supplier: NotRequired[SupplierTypedDict]
    r"""Supplier details"""
    delivery_date: NotRequired[date]
    r"""The delivery date of the ordered goods or services"""
    ship_to: NotRequired[ShipToTypedDict]
    r"""The recipient of the goods or services"""
    bill_to: NotRequired[BillToTypedDict]
    r"""The recipient of the invoice"""
    line_items: NotRequired[List[PurchaseOrderFieldsLineItemsTypedDict]]
    r"""List of line items in the invoice"""
    taxes: NotRequired[PurchaseOrderFieldsTaxesTypedDict]
    r"""Tax information"""


class PurchaseOrderFields(BaseModel):
    r"""Fields extracted from a purchase order"""

    order_number: Annotated[Optional[str], pydantic.Field(alias="orderNumber")] = None
    r"""The number of the purchase order"""

    order_date: Annotated[Optional[date], pydantic.Field(alias="orderDate")] = None
    r"""The date when the purchase order was created"""

    total: Optional[float] = None
    r"""The total amount of the purchase order"""

    currency: Optional[str] = None
    r"""The currency of the total amount. If no total amount is indicated, this field will be empty."""

    buyer: Optional[Buyer] = None
    r"""Buyer details"""

    supplier: Optional[Supplier] = None
    r"""Supplier details"""

    delivery_date: Annotated[Optional[date], pydantic.Field(alias="deliveryDate")] = (
        None
    )
    r"""The delivery date of the ordered goods or services"""

    ship_to: Annotated[Optional[ShipTo], pydantic.Field(alias="shipTo")] = None
    r"""The recipient of the goods or services"""

    bill_to: Annotated[Optional[BillTo], pydantic.Field(alias="billTo")] = None
    r"""The recipient of the invoice"""

    line_items: Annotated[
        Optional[List[PurchaseOrderFieldsLineItems]], pydantic.Field(alias="lineItems")
    ] = None
    r"""List of line items in the invoice"""

    taxes: Optional[PurchaseOrderFieldsTaxes] = None
    r"""Tax information"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PartyTypedDict(TypedDict):
    organization_name: NotRequired[str]
    r"""The legal name of a party"""
    person_name: NotRequired[str]
    r"""The name of the individual who represents or acts on behalf of a party"""
    role: NotRequired[str]
    r"""The role of a party. Examples of roles include seller, buyer, service provider, or client"""
    address: NotRequired[str]
    r"""The address of a party"""


class Party(BaseModel):
    organization_name: Annotated[
        Optional[str], pydantic.Field(alias="organizationName")
    ] = None
    r"""The legal name of a party"""

    person_name: Annotated[Optional[str], pydantic.Field(alias="personName")] = None
    r"""The name of the individual who represents or acts on behalf of a party"""

    role: Optional[str] = None
    r"""The role of a party. Examples of roles include seller, buyer, service provider, or client"""

    address: Optional[str] = None
    r"""The address of a party"""


class BasicContractFieldsTypedDict(TypedDict):
    r"""Fields extracted from a basic contract"""

    title: NotRequired[str]
    r"""The title of the contract"""
    party: NotRequired[List[PartyTypedDict]]
    deal_amount: NotRequired[float]
    r"""The amount or value of the contract"""
    agreement_date: NotRequired[date]
    r"""The date on which the contract was officially executed or agreed upon by the parties"""
    effective_date: NotRequired[date]
    r"""The start date of the contract"""
    expiration_date: NotRequired[date]
    r"""The expiration date of the contract"""
    initial_term: NotRequired[str]
    r"""The initial period of time for which the contract will be in effect before any renewal or extension options are considered"""
    renewal_term: NotRequired[str]
    r"""The additional period of time for which the contract can be extended or renewed after the initial term has expired"""
    governing_law: NotRequired[str]
    r"""The jurisdiction that will govern the interpretation, enforcement, and resolution of any disputes or legal issues arising from the contract"""
    security_deposit: NotRequired[float]
    r"""The amount of money that the party providing the security deposit is required to pay"""
    insurance_clause: NotRequired[str]
    r"""The insurance requirements and responsibilities of the parties"""
    limitation_of_liability: NotRequired[float]
    r"""The maximum monetary amount for which a party can be held liable in the event of a breach or dispute"""
    confidentiality_clause: NotRequired[str]
    r"""The terms and conditions regarding the confidentiality of the information shared between the parties"""
    indemnity_clause: NotRequired[str]
    r"""The terms and conditions related to indemnification"""
    non_compete_clause: NotRequired[str]
    r"""The activities or businesses that a party or parties are prohibited from engaging in"""


class BasicContractFields(BaseModel):
    r"""Fields extracted from a basic contract"""

    title: Optional[str] = None
    r"""The title of the contract"""

    party: Optional[List[Party]] = None

    deal_amount: Annotated[Optional[float], pydantic.Field(alias="dealAmount")] = None
    r"""The amount or value of the contract"""

    agreement_date: Annotated[Optional[date], pydantic.Field(alias="agreementDate")] = (
        None
    )
    r"""The date on which the contract was officially executed or agreed upon by the parties"""

    effective_date: Annotated[Optional[date], pydantic.Field(alias="effectiveDate")] = (
        None
    )
    r"""The start date of the contract"""

    expiration_date: Annotated[
        Optional[date], pydantic.Field(alias="expirationDate")
    ] = None
    r"""The expiration date of the contract"""

    initial_term: Annotated[Optional[str], pydantic.Field(alias="initialTerm")] = None
    r"""The initial period of time for which the contract will be in effect before any renewal or extension options are considered"""

    renewal_term: Annotated[Optional[str], pydantic.Field(alias="renewalTerm")] = None
    r"""The additional period of time for which the contract can be extended or renewed after the initial term has expired"""

    governing_law: Annotated[Optional[str], pydantic.Field(alias="governingLaw")] = None
    r"""The jurisdiction that will govern the interpretation, enforcement, and resolution of any disputes or legal issues arising from the contract"""

    security_deposit: Annotated[
        Optional[float], pydantic.Field(alias="securityDeposit")
    ] = None
    r"""The amount of money that the party providing the security deposit is required to pay"""

    insurance_clause: Annotated[
        Optional[str], pydantic.Field(alias="insuranceClause")
    ] = None
    r"""The insurance requirements and responsibilities of the parties"""

    limitation_of_liability: Annotated[
        Optional[float], pydantic.Field(alias="limitationOfLiability")
    ] = None
    r"""The maximum monetary amount for which a party can be held liable in the event of a breach or dispute"""

    confidentiality_clause: Annotated[
        Optional[str], pydantic.Field(alias="confidentialityClause")
    ] = None
    r"""The terms and conditions regarding the confidentiality of the information shared between the parties"""

    indemnity_clause: Annotated[
        Optional[str], pydantic.Field(alias="indemnityClause")
    ] = None
    r"""The terms and conditions related to indemnification"""

    non_compete_clause: Annotated[
        Optional[str], pydantic.Field(alias="nonCompeteClause")
    ] = None
    r"""The activities or businesses that a party or parties are prohibited from engaging in"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class BillOfLadingFieldsTermsTypedDict(TypedDict):
    prepaid: NotRequired[bool]
    r"""Indicates if the transport expenses are charged to the shipper"""
    collect: NotRequired[bool]
    r"""Indicates if the transport expenses are charged to the consignee"""
    third_party: NotRequired[bool]
    r"""Indicates if the transport expenses are charged to a third party"""


class BillOfLadingFieldsTerms(BaseModel):
    prepaid: Optional[bool] = None
    r"""Indicates if the transport expenses are charged to the shipper"""

    collect: Optional[bool] = None
    r"""Indicates if the transport expenses are charged to the consignee"""

    third_party: Annotated[Optional[bool], pydantic.Field(alias="thirdParty")] = None
    r"""Indicates if the transport expenses are charged to a third party"""


class BillOfLadingFieldsShipperTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The shipper's name"""
    address: NotRequired[str]
    r"""The shipper's address"""


class BillOfLadingFieldsShipper(BaseModel):
    name: Optional[str] = None
    r"""The shipper's name"""

    address: Optional[str] = None
    r"""The shipper's address"""


class BillOfLadingFieldsCarrierTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the carrier"""
    scac_code: NotRequired[str]
    r"""An SCAC (Standard Carrier Alpha Code) code used to identify transport companies"""


class BillOfLadingFieldsCarrier(BaseModel):
    name: Optional[str] = None
    r"""The name of the carrier"""

    scac_code: Annotated[Optional[str], pydantic.Field(alias="scacCode")] = None
    r"""An SCAC (Standard Carrier Alpha Code) code used to identify transport companies"""


class BillOfLadingFieldsConsigneeTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The consignee's name"""
    customer_id: NotRequired[str]
    r"""The consignee's customer ID"""
    address: NotRequired[str]
    r"""The consignee's address"""


class BillOfLadingFieldsConsignee(BaseModel):
    name: Optional[str] = None
    r"""The consignee's name"""

    customer_id: Annotated[Optional[str], pydantic.Field(alias="customerId")] = None
    r"""The consignee's customer ID"""

    address: Optional[str] = None
    r"""The consignee's address"""


class BillOfLadingFieldsBillToTypedDict(TypedDict):
    r"""Information about the organization or business unit responsible for paying the freight fees"""

    name: NotRequired[str]
    r"""The name of the organization or business unit responsible for paying the freight fees"""
    address: NotRequired[str]
    r"""The address of the organization or business unit responsible for paying the freight fees"""


class BillOfLadingFieldsBillTo(BaseModel):
    r"""Information about the organization or business unit responsible for paying the freight fees"""

    name: Optional[str] = None
    r"""The name of the organization or business unit responsible for paying the freight fees"""

    address: Optional[str] = None
    r"""The address of the organization or business unit responsible for paying the freight fees"""


class BillOfLadingFieldsTypedDict(TypedDict):
    r"""Fields extracted from a bill of lading"""

    bol_number: NotRequired[str]
    r"""Bill of lading number"""
    bol_date: NotRequired[date]
    r"""The date on which the bill of lading was made"""
    po_number: NotRequired[str]
    r"""The purchase order number"""
    sales_order_number: NotRequired[str]
    r"""The sales order number"""
    shipment_id: NotRequired[str]
    r"""The shipment identifier"""
    shipment_date: NotRequired[date]
    r"""The date of the shipment"""
    pro_number: NotRequired[str]
    r"""A shipment identifier assigned by the carrier"""
    vehicle_number: NotRequired[str]
    r"""The number of the transport vehicle or carriage"""
    seal_number: NotRequired[str]
    r"""The seal number"""
    terms: NotRequired[BillOfLadingFieldsTermsTypedDict]
    nmfc_code: NotRequired[str]
    r"""National Motor Freight Classification shipment identifier"""
    class_: NotRequired[str]
    r"""National Motor Freight Classification shipment class"""
    port_of_loading: NotRequired[str]
    r"""The origin of the shipment"""
    port_of_discharge: NotRequired[str]
    r"""The destination of the shipment"""
    special_instructions: NotRequired[str]
    r"""Special handling instructions for the carrier regarding the shipment"""
    number_of_packages: NotRequired[float]
    r"""The total number of packages"""
    package_type: NotRequired[str]
    r"""The package type"""
    total_weight_nonmetric: NotRequired[float]
    r"""The total weight of the shipment in non-metric units of measurement"""
    total_weight_uom_nonmetric: NotRequired[str]
    r"""The non-metric unit of measurement used for the total weight"""
    total_weight_metric: NotRequired[float]
    r"""The total weight of the shipment in metric units of measurement"""
    total_weight_uom_metric: NotRequired[str]
    r"""The metric unit of measurement used for the total weight"""
    hazardous_material: NotRequired[bool]
    r"""Indicates whether the shipment contains any items classified as hazardous"""
    shipper: NotRequired[BillOfLadingFieldsShipperTypedDict]
    carrier: NotRequired[BillOfLadingFieldsCarrierTypedDict]
    consignee: NotRequired[BillOfLadingFieldsConsigneeTypedDict]
    bill_to: NotRequired[BillOfLadingFieldsBillToTypedDict]
    r"""Information about the organization or business unit responsible for paying the freight fees"""


class BillOfLadingFields(BaseModel):
    r"""Fields extracted from a bill of lading"""

    bol_number: Annotated[Optional[str], pydantic.Field(alias="bolNumber")] = None
    r"""Bill of lading number"""

    bol_date: Annotated[Optional[date], pydantic.Field(alias="bolDate")] = None
    r"""The date on which the bill of lading was made"""

    po_number: Annotated[Optional[str], pydantic.Field(alias="poNumber")] = None
    r"""The purchase order number"""

    sales_order_number: Annotated[
        Optional[str], pydantic.Field(alias="salesOrderNumber")
    ] = None
    r"""The sales order number"""

    shipment_id: Annotated[Optional[str], pydantic.Field(alias="shipmentId")] = None
    r"""The shipment identifier"""

    shipment_date: Annotated[Optional[date], pydantic.Field(alias="shipmentDate")] = (
        None
    )
    r"""The date of the shipment"""

    pro_number: Annotated[Optional[str], pydantic.Field(alias="proNumber")] = None
    r"""A shipment identifier assigned by the carrier"""

    vehicle_number: Annotated[Optional[str], pydantic.Field(alias="vehicleNumber")] = (
        None
    )
    r"""The number of the transport vehicle or carriage"""

    seal_number: Annotated[Optional[str], pydantic.Field(alias="sealNumber")] = None
    r"""The seal number"""

    terms: Optional[BillOfLadingFieldsTerms] = None

    nmfc_code: Annotated[Optional[str], pydantic.Field(alias="nmfcCode")] = None
    r"""National Motor Freight Classification shipment identifier"""

    class_: Annotated[Optional[str], pydantic.Field(alias="class")] = None
    r"""National Motor Freight Classification shipment class"""

    port_of_loading: Annotated[Optional[str], pydantic.Field(alias="portOfLoading")] = (
        None
    )
    r"""The origin of the shipment"""

    port_of_discharge: Annotated[
        Optional[str], pydantic.Field(alias="portOfDischarge")
    ] = None
    r"""The destination of the shipment"""

    special_instructions: Annotated[
        Optional[str], pydantic.Field(alias="specialInstructions")
    ] = None
    r"""Special handling instructions for the carrier regarding the shipment"""

    number_of_packages: Annotated[
        Optional[float], pydantic.Field(alias="numberOfPackages")
    ] = None
    r"""The total number of packages"""

    package_type: Annotated[Optional[str], pydantic.Field(alias="packageType")] = None
    r"""The package type"""

    total_weight_nonmetric: Annotated[
        Optional[float], pydantic.Field(alias="totalWeightNonmetric")
    ] = None
    r"""The total weight of the shipment in non-metric units of measurement"""

    total_weight_uom_nonmetric: Annotated[
        Optional[str], pydantic.Field(alias="totalWeightUomNonmetric")
    ] = None
    r"""The non-metric unit of measurement used for the total weight"""

    total_weight_metric: Annotated[
        Optional[float], pydantic.Field(alias="totalWeightMetric")
    ] = None
    r"""The total weight of the shipment in metric units of measurement"""

    total_weight_uom_metric: Annotated[
        Optional[str], pydantic.Field(alias="totalWeightUomMetric")
    ] = None
    r"""The metric unit of measurement used for the total weight"""

    hazardous_material: Annotated[
        Optional[bool], pydantic.Field(alias="hazardousMaterial")
    ] = None
    r"""Indicates whether the shipment contains any items classified as hazardous"""

    shipper: Optional[BillOfLadingFieldsShipper] = None

    carrier: Optional[BillOfLadingFieldsCarrier] = None

    consignee: Optional[BillOfLadingFieldsConsignee] = None

    bill_to: Annotated[
        Optional[BillOfLadingFieldsBillTo], pydantic.Field(alias="billTo")
    ] = None
    r"""Information about the organization or business unit responsible for paying the freight fees"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import datetime
from enum import Enum
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class Status(str, Enum):
    r"""The status of the document. Valid values are `Pending`, `Processing`, `Processed`, `Failed`, `Canceled`."""

    PENDING = "Pending"
    PROCESSING = "Processing"
    PROCESSED = "Processed"
    FAILED = "Failed"
    CANCELED = "Canceled"


class ErrorsTypedDict(TypedDict):
    message: str


class Errors(BaseModel):
    message: str


class DocumentTypedDict(TypedDict):
    r"""Represents a document that has been submitted for processing."""

    id: str
    r"""The id of the document."""
    name: str
    r"""The name of the document."""
    created_at: datetime
    r"""Timestamp at which the document was created."""
    status: Status
    r"""The status of the document. Valid values are `Pending`, `Processing`, `Processed`, `Failed`, `Canceled`."""
    page_count: int
    r"""The number of pages associated with the document that have been processed. This number will always be at least 1."""
    model: NotRequired[str]
    r"""The model used to process the document."""
    errors: NotRequired[List[ErrorsTypedDict]]
    r"""An array of errors that occurred while processing the document."""


class Document(BaseModel):
    r"""Represents a document that has been submitted for processing."""

    id: str
    r"""The id of the document."""

    name: str
    r"""The name of the document."""

    created_at: Annotated[datetime, pydantic.Field(alias="createdAt")]
    r"""Timestamp at which the document was created."""

    status: Status
    r"""The status of the document. Valid values are `Pending`, `Processing`, `Processed`, `Failed`, `Canceled`."""

    page_count: Annotated[int, pydantic.Field(alias="pageCount")]
    r"""The number of pages associated with the document that have been processed. This number will always be at least 1."""

    model: Optional[str] = None
    r"""The model used to process the document."""

    errors: Optional[List[Errors]] = None
    r"""An array of errors that occurred while processing the document."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PackingListFieldsShipperTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The shipper's name"""
    address: NotRequired[str]
    r"""The shipper's address"""
    tax_id: NotRequired[str]
    r"""The shipper's taxpayer identifier"""
    iban: NotRequired[str]
    r"""The shipper's International Bank Account Number"""
    bank_account: NotRequired[str]
    r"""The shipper's bank account"""
    bank_code: NotRequired[str]
    r"""The shipper's bank code"""


class PackingListFieldsShipper(BaseModel):
    name: Optional[str] = None
    r"""The shipper's name"""

    address: Optional[str] = None
    r"""The shipper's address"""

    tax_id: Annotated[Optional[str], pydantic.Field(alias="taxId")] = None
    r"""The shipper's taxpayer identifier"""

    iban: Optional[str] = None
    r"""The shipper's International Bank Account Number"""

    bank_account: Annotated[Optional[str], pydantic.Field(alias="bankAccount")] = None
    r"""The shipper's bank account"""

    bank_code: Annotated[Optional[str], pydantic.Field(alias="bankCode")] = None
    r"""The shipper's bank code"""


class PackingListFieldsConsigneeTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The consignee's name"""
    address: NotRequired[str]
    r"""The consignee's address"""


class PackingListFieldsConsignee(BaseModel):
    name: Optional[str] = None
    r"""The consignee's name"""

    address: Optional[str] = None
    r"""The consignee's address"""


class PackingListFieldsBuyerTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The buyer's name"""
    address: NotRequired[str]
    r"""The buyer's address"""


class PackingListFieldsBuyer(BaseModel):
    name: Optional[str] = None
    r"""The buyer's name"""

    address: Optional[str] = None
    r"""The buyer's address"""


class PackingListFieldsBillToTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The recipient of the invoice's name"""
    address: NotRequired[str]
    r"""The recipient of the invoice's address"""


class PackingListFieldsBillTo(BaseModel):
    name: Optional[str] = None
    r"""The recipient of the invoice's name"""

    address: Optional[str] = None
    r"""The recipient of the invoice's address"""


class PackingListFieldsPurchaseOrderTypedDict(TypedDict):
    number: NotRequired[str]
    r"""The purchase order number"""
    date_: NotRequired[str]
    r"""The date of the corresponding purchase order"""


class PackingListFieldsPurchaseOrder(BaseModel):
    number: Optional[str] = None
    r"""The purchase order number"""

    date_: Annotated[Optional[str], pydantic.Field(alias="date")] = None
    r"""The date of the corresponding purchase order"""


class PackingListFieldsLineItemsTypedDict(TypedDict):
    position: NotRequired[float]
    r"""The number of the item in the list"""
    article_number: NotRequired[str]
    r"""The article number"""
    order_number: NotRequired[str]
    r"""The purchase order number"""
    invoice_number: NotRequired[str]
    r"""The invoice number"""
    country_of_origin: NotRequired[str]
    r"""The country of origin of goods"""
    container_number: NotRequired[str]
    r"""The container (container, box, pallet) number"""
    description: NotRequired[str]
    r"""A description of the goods"""
    quantity: NotRequired[float]
    r"""Number of items of goods delivered to the destination"""
    unit_of_measurement: NotRequired[str]
    r"""The unit of measurement used for the quantity of goods"""
    package_quantity: NotRequired[float]
    r"""The total number of shipments containing the goods"""
    package_unit_of_measurement: NotRequired[str]
    r"""The unit of measurement used for packages"""
    net_weight: NotRequired[float]
    r"""The net weight of the goods"""
    net_weight_unit_of_measurement: NotRequired[str]
    r"""The unit of measurement used for the net weight"""
    gross_weight: NotRequired[float]
    r"""The gross weight of the goods"""
    gross_weight_unit_of_measurement: NotRequired[str]
    r"""The unit of measurement used for the gross weight"""
    volume: NotRequired[float]
    r"""The volume of the goods"""
    volume_unit_of_measurement: NotRequired[str]
    r"""The unit of measurement used for the volume"""
    dimensions: NotRequired[str]
    r"""The dimensions of the goods"""
    dimensions_unit_of_measurement: NotRequired[str]
    r"""The unit of measurement used for the dimensions"""
    length: NotRequired[float]
    r"""The length of each item in the shipment"""
    width: NotRequired[float]
    r"""The width of each item in the shipment"""
    height: NotRequired[float]
    r"""The height of each item in the shipment"""


class PackingListFieldsLineItems(BaseModel):
    position: Optional[float] = None
    r"""The number of the item in the list"""

    article_number: Annotated[Optional[str], pydantic.Field(alias="articleNumber")] = (
        None
    )
    r"""The article number"""

    order_number: Annotated[Optional[str], pydantic.Field(alias="orderNumber")] = None
    r"""The purchase order number"""

    invoice_number: Annotated[Optional[str], pydantic.Field(alias="invoiceNumber")] = (
        None
    )
    r"""The invoice number"""

    country_of_origin: Annotated[
        Optional[str], pydantic.Field(alias="countryOfOrigin")
    ] = None
    r"""The country of origin of goods"""

    container_number: Annotated[
        Optional[str], pydantic.Field(alias="containerNumber")
    ] = None
    r"""The container (container, box, pallet) number"""

    description: Optional[str] = None
    r"""A description of the goods"""

    quantity: Optional[float] = None
    r"""Number of items of goods delivered to the destination"""

    unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="unitOfMeasurement")
    ] = None
    r"""The unit of measurement used for the quantity of goods"""

    package_quantity: Annotated[
        Optional[float], pydantic.Field(alias="packageQuantity")
    ] = None
    r"""The total number of shipments containing the goods"""

    package_unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="packageUnitOfMeasurement")
    ] = None
    r"""The unit of measurement used for packages"""

    net_weight: Annotated[Optional[float], pydantic.Field(alias="netWeight")] = None
    r"""The net weight of the goods"""

    net_weight_unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="netWeightUnitOfMeasurement")
    ] = None
    r"""The unit of measurement used for the net weight"""

    gross_weight: Annotated[Optional[float], pydantic.Field(alias="grossWeight")] = None
    r"""The gross weight of the goods"""

    gross_weight_unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="grossWeightUnitOfMeasurement")
    ] = None
    r"""The unit of measurement used for the gross weight"""

    volume: Optional[float] = None
    r"""The volume of the goods"""

    volume_unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="volumeUnitOfMeasurement")
    ] = None
    r"""The unit of measurement used for the volume"""

    dimensions: Optional[str] = None
    r"""The dimensions of the goods"""

    dimensions_unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="dimensionsUnitOfMeasurement")
    ] = None
    r"""The unit of measurement used for the dimensions"""

    length: Optional[float] = None
    r"""The length of each item in the shipment"""

    width: Optional[float] = None
    r"""The width of each item in the shipment"""

    height: Optional[float] = None
    r"""The height of each item in the shipment"""


class TotalQuantityTypedDict(TypedDict):
    amount: NotRequired[float]
    r"""The total number of units of goods"""
    unit_of_measurement: NotRequired[str]
    r"""The unit of measurement for the total quantity"""


class TotalQuantity(BaseModel):
    amount: Optional[float] = None
    r"""The total number of units of goods"""

    unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="unitOfMeasurement")
    ] = None
    r"""The unit of measurement for the total quantity"""


class TotalPackagesTypedDict(TypedDict):
    amount: NotRequired[float]
    r"""The total number of shipment units"""
    unit_of_measurement: NotRequired[str]
    r"""The unit of measurement for the total packages"""


class TotalPackages(BaseModel):
    amount: Optional[float] = None
    r"""The total number of shipment units"""

    unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="unitOfMeasurement")
    ] = None
    r"""The unit of measurement for the total packages"""


class TotalNetWeightTypedDict(TypedDict):
    amount: NotRequired[float]
    r"""The net weight of the goods"""
    unit_of_measurement: NotRequired[str]
    r"""The unit of measurement for the total net weight"""


class TotalNetWeight(BaseModel):
    amount: Optional[float] = None
    r"""The net weight of the goods"""

    unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="unitOfMeasurement")
    ] = None
    r"""The unit of measurement for the total net weight"""


class TotalGrossWeightTypedDict(TypedDict):
    amount: NotRequired[float]
    r"""The gross weight of the goods"""
    unit_of_measurement: NotRequired[str]
    r"""The unit of measurement for the total gross weight"""


class TotalGrossWeight(BaseModel):
    amount: Optional[float] = None
    r"""The gross weight of the goods"""

    unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="unitOfMeasurement")
    ] = None
    r"""The unit of measurement for the total gross weight"""


class TotalVolumeTypedDict(TypedDict):
    amount: NotRequired[float]
    r"""The total volume of the goods"""
    unit_of_measurement: NotRequired[str]
    r"""The unit of measurement for the total volume"""


class TotalVolume(BaseModel):
    amount: Optional[float] = None
    r"""The total volume of the goods"""

    unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="unitOfMeasurement")
    ] = None
    r"""The unit of measurement for the total volume"""


class TotalDimensionsTypedDict(TypedDict):
    amount: NotRequired[float]
    r"""The total dimensions of the goods"""
    unit_of_measurement: NotRequired[str]
    r"""The unit of measurement for the total dimensions"""


class TotalDimensions(BaseModel):
    amount: Optional[float] = None
    r"""The total dimensions of the goods"""

    unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="unitOfMeasurement")
    ] = None
    r"""The unit of measurement for the total dimensions"""


class PackingListFieldsTypedDict(TypedDict):
    r"""Fields extracted from a packing list"""

    shipper: NotRequired[PackingListFieldsShipperTypedDict]
    consignee: NotRequired[PackingListFieldsConsigneeTypedDict]
    buyer: NotRequired[PackingListFieldsBuyerTypedDict]
    bill_to: NotRequired[PackingListFieldsBillToTypedDict]
    packing_list_number: NotRequired[str]
    r"""The packing list number"""
    packing_list_date: NotRequired[date]
    r"""The date of the packing list"""
    invoice_number: NotRequired[str]
    r"""The number of the invoice for the shipped goods"""
    invoice_date: NotRequired[date]
    r"""The date of the invoice"""
    purchase_order: NotRequired[List[PackingListFieldsPurchaseOrderTypedDict]]
    bill_of_lading_number: NotRequired[str]
    r"""The bill of lading number"""
    country_of_origin: NotRequired[str]
    r"""The country where the shipped goods were manufactured"""
    country_of_final_destination: NotRequired[str]
    r"""The country of destination of the shipped goods"""
    mode_of_transportation: NotRequired[str]
    r"""The shipment method to be used (AIR, SEA/OCEAN, RAIL, GROUND/TRUCK, Intermodal)"""
    shipping_date: NotRequired[date]
    r"""The date of the shipment"""
    incoterm: NotRequired[str]
    r"""The delivery terms. One of: EXW (EX Works), FCA (Free Carrier), FAS (Free Alongside Ship), FOB (Free On Board), CFR (Cost And Freight), CIF (Cost Insurance Freight), DAP (Delivered At Place), DPU (Delivered at Place Unloaded), CPT (Carriage Paid To), CIP (Carriage Insurance Paid), DDP (Delivered Duty Paid), DDU (Delivered Duty Unpaid)"""
    line_items: NotRequired[List[PackingListFieldsLineItemsTypedDict]]
    total_quantity: NotRequired[TotalQuantityTypedDict]
    total_packages: NotRequired[TotalPackagesTypedDict]
    total_net_weight: NotRequired[TotalNetWeightTypedDict]
    total_gross_weight: NotRequired[TotalGrossWeightTypedDict]
    total_volume: NotRequired[TotalVolumeTypedDict]
    total_dimensions: NotRequired[TotalDimensionsTypedDict]


class PackingListFields(BaseModel):
    r"""Fields extracted from a packing list"""

    shipper: Optional[PackingListFieldsShipper] = None

    consignee: Optional[PackingListFieldsConsignee] = None

    buyer: Optional[PackingListFieldsBuyer] = None

    bill_to: Annotated[
        Optional[PackingListFieldsBillTo], pydantic.Field(alias="billTo")
    ] = None

    packing_list_number: Annotated[
        Optional[str], pydantic.Field(alias="packingListNumber")
    ] = None
    r"""The packing list number"""

    packing_list_date: Annotated[
        Optional[date], pydantic.Field(alias="packingListDate")
    ] = None
    r"""The date of the packing list"""

    invoice_number: Annotated[Optional[str], pydantic.Field(alias="invoiceNumber")] = (
        None
    )
    r"""The number of the invoice for the shipped goods"""

    invoice_date: Annotated[Optional[date], pydantic.Field(alias="invoiceDate")] = None
    r"""The date of the invoice"""

    purchase_order: Annotated[
        Optional[List[PackingListFieldsPurchaseOrder]],
        pydantic.Field(alias="purchaseOrder"),
    ] = None

    bill_of_lading_number: Annotated[
        Optional[str], pydantic.Field(alias="billOfLadingNumber")
    ] = None
    r"""The bill of lading number"""

    country_of_origin: Annotated[
        Optional[str], pydantic.Field(alias="countryOfOrigin")
    ] = None
    r"""The country where the shipped goods were manufactured"""

    country_of_final_destination: Annotated[
        Optional[str], pydantic.Field(alias="countryOfFinalDestination")
    ] = None
    r"""The country of destination of the shipped goods"""

    mode_of_transportation: Annotated[
        Optional[str], pydantic.Field(alias="modeOfTransportation")
    ] = None
    r"""The shipment method to be used (AIR, SEA/OCEAN, RAIL, GROUND/TRUCK, Intermodal)"""

    shipping_date: Annotated[Optional[date], pydantic.Field(alias="shippingDate")] = (
        None
    )
    r"""The date of the shipment"""

    incoterm: Optional[str] = None
    r"""The delivery terms. One of: EXW (EX Works), FCA (Free Carrier), FAS (Free Alongside Ship), FOB (Free On Board), CFR (Cost And Freight), CIF (Cost Insurance Freight), DAP (Delivered At Place), DPU (Delivered at Place Unloaded), CPT (Carriage Paid To), CIP (Carriage Insurance Paid), DDP (Delivered Duty Paid), DDU (Delivered Duty Unpaid)"""

    line_items: Annotated[
        Optional[List[PackingListFieldsLineItems]], pydantic.Field(alias="lineItems")
    ] = None

    total_quantity: Annotated[
        Optional[TotalQuantity], pydantic.Field(alias="totalQuantity")
    ] = None

    total_packages: Annotated[
        Optional[TotalPackages], pydantic.Field(alias="totalPackages")
    ] = None

    total_net_weight: Annotated[
        Optional[TotalNetWeight], pydantic.Field(alias="totalNetWeight")
    ] = None

    total_gross_weight: Annotated[
        Optional[TotalGrossWeight], pydantic.Field(alias="totalGrossWeight")
    ] = None

    total_volume: Annotated[
        Optional[TotalVolume], pydantic.Field(alias="totalVolume")
    ] = None

    total_dimensions: Annotated[
        Optional[TotalDimensions], pydantic.Field(alias="totalDimensions")
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CommercialInvoiceFieldsConsigneeTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the consignee"""
    tax_id: NotRequired[str]
    r"""The international tax ID of the consignee"""
    address: NotRequired[str]
    r"""The address of the consignee"""
    consignee_id: NotRequired[str]
    r"""The unique identifier of the consignee"""
    postal_code: NotRequired[str]
    r"""The postal code of the consignee"""
    street: NotRequired[str]
    r"""The street component of the consignee address"""
    city: NotRequired[str]
    r"""The city component of the consignee address"""
    state_or_province: NotRequired[str]
    r"""The state or province component of the consignee address"""
    country: NotRequired[str]
    r"""The country component of the consignee address"""


class CommercialInvoiceFieldsConsignee(BaseModel):
    name: Optional[str] = None
    r"""The name of the consignee"""

    tax_id: Annotated[Optional[str], pydantic.Field(alias="taxId")] = None
    r"""The international tax ID of the consignee"""

    address: Optional[str] = None
    r"""The address of the consignee"""

    consignee_id: Annotated[Optional[str], pydantic.Field(alias="consigneeId")] = None
    r"""The unique identifier of the consignee"""

    postal_code: Annotated[Optional[str], pydantic.Field(alias="postalCode")] = None
    r"""The postal code of the consignee"""

    street: Optional[str] = None
    r"""The street component of the consignee address"""

    city: Optional[str] = None
    r"""The city component of the consignee address"""

    state_or_province: Annotated[
        Optional[str], pydantic.Field(alias="stateOrProvince")
    ] = None
    r"""The state or province component of the consignee address"""

    country: Optional[str] = None
    r"""The country component of the consignee address"""


class CommercialInvoiceFieldsVendorTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the sender of the goods"""
    tax_id: NotRequired[str]
    r"""The international tax ID of the sender of the goods"""
    address: NotRequired[str]
    r"""The address of the sender of the goods"""
    vendor_id: NotRequired[str]
    r"""The unique identifier of the sender of the goods"""
    postal_code: NotRequired[str]
    r"""The postal code of the sender of the goods"""
    street: NotRequired[str]
    r"""The Street component of the sender of the goods address"""
    city: NotRequired[str]
    r"""The City component of the sender of the goods address"""
    state_or_province: NotRequired[str]
    r"""The State or Province component of the sender of the goods address"""
    country: NotRequired[str]
    r"""The Country component of the sender of the goods address"""
    national_tax_id: NotRequired[str]
    r"""The national tax ID of the sender of the goods"""
    iban: NotRequired[str]
    r"""The IBAN (International Bank Account Number) of the sender of the goods"""
    bank_code: NotRequired[str]
    r"""The bank code of the sender of the goods"""
    bank_account: NotRequired[str]
    r"""The bank account of the sender of the goods"""


class CommercialInvoiceFieldsVendor(BaseModel):
    name: Optional[str] = None
    r"""The name of the sender of the goods"""

    tax_id: Annotated[Optional[str], pydantic.Field(alias="taxId")] = None
    r"""The international tax ID of the sender of the goods"""

    address: Optional[str] = None
    r"""The address of the sender of the goods"""

    vendor_id: Annotated[Optional[str], pydantic.Field(alias="vendorId")] = None
    r"""The unique identifier of the sender of the goods"""

    postal_code: Annotated[Optional[str], pydantic.Field(alias="postalCode")] = None
    r"""The postal code of the sender of the goods"""

    street: Optional[str] = None
    r"""The Street component of the sender of the goods address"""

    city: Optional[str] = None
    r"""The City component of the sender of the goods address"""

    state_or_province: Annotated[
        Optional[str], pydantic.Field(alias="stateOrProvince")
    ] = None
    r"""The State or Province component of the sender of the goods address"""

    country: Optional[str] = None
    r"""The Country component of the sender of the goods address"""

    national_tax_id: Annotated[Optional[str], pydantic.Field(alias="nationalTaxId")] = (
        None
    )
    r"""The national tax ID of the sender of the goods"""

    iban: Optional[str] = None
    r"""The IBAN (International Bank Account Number) of the sender of the goods"""

    bank_code: Annotated[Optional[str], pydantic.Field(alias="bankCode")] = None
    r"""The bank code of the sender of the goods"""

    bank_account: Annotated[Optional[str], pydantic.Field(alias="bankAccount")] = None
    r"""The bank account of the sender of the goods"""


class CommercialInvoiceFieldsShipToTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the recipient of the goods"""
    address: NotRequired[str]
    r"""The address of the recipient of the goods"""


class CommercialInvoiceFieldsShipTo(BaseModel):
    name: Optional[str] = None
    r"""The name of the recipient of the goods"""

    address: Optional[str] = None
    r"""The address of the recipient of the goods"""


class CommercialInvoiceFieldsBillToTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the recipient of the invoice for the goods specified in the document"""
    address: NotRequired[str]
    r"""The address of the recipient of the invoice for the goods specified in the document"""


class CommercialInvoiceFieldsBillTo(BaseModel):
    name: Optional[str] = None
    r"""The name of the recipient of the invoice for the goods specified in the document"""

    address: Optional[str] = None
    r"""The address of the recipient of the invoice for the goods specified in the document"""


class CommercialInvoiceFieldsAdditionalCostsTypedDict(TypedDict):
    type: NotRequired[str]
    r"""The type of additional cost"""
    amount: NotRequired[float]
    r"""The amount of the additional cost"""
    currency: NotRequired[str]
    r"""The currency of the additional cost"""


class CommercialInvoiceFieldsAdditionalCosts(BaseModel):
    type: Optional[str] = None
    r"""The type of additional cost"""

    amount: Optional[float] = None
    r"""The amount of the additional cost"""

    currency: Optional[str] = None
    r"""The currency of the additional cost"""


class CommercialInvoiceFieldsLineItemsTypedDict(TypedDict):
    position: NotRequired[float]
    r"""The number of the line item"""
    country_of_origin: NotRequired[str]
    r"""The country where the line item was manufactured"""
    hs_code: NotRequired[str]
    r"""The Harmonized System code of the goods"""
    description: NotRequired[str]
    r"""A description of the line item"""
    quantity: NotRequired[float]
    r"""The number of units purchased"""
    uom: NotRequired[str]
    r"""The unit of measurement used for the line item"""
    unit_price: NotRequired[float]
    r"""The price of one unit of the goods"""
    total_price: NotRequired[float]
    r"""The total price of the line item, including additional charges and discounts"""
    currency: NotRequired[str]
    r"""The currency of the line item"""
    net_weight: NotRequired[float]
    r"""The net weight of the line item (that is, without the packaging)"""
    net_weight_uom: NotRequired[str]
    r"""The unit of measurement used for the net weight"""
    gross_weight: NotRequired[float]
    r"""The gross weight of the line item (that is, with the packaging)"""
    gross_weight_uom: NotRequired[str]
    r"""The unit of measurement used for the gross weight"""


class CommercialInvoiceFieldsLineItems(BaseModel):
    position: Optional[float] = None
    r"""The number of the line item"""

    country_of_origin: Annotated[
        Optional[str], pydantic.Field(alias="countryOfOrigin")
    ] = None
    r"""The country where the line item was manufactured"""

    hs_code: Annotated[Optional[str], pydantic.Field(alias="hsCode")] = None
    r"""The Harmonized System code of the goods"""

    description: Optional[str] = None
    r"""A description of the line item"""

    quantity: Optional[float] = None
    r"""The number of units purchased"""

    uom: Optional[str] = None
    r"""The unit of measurement used for the line item"""

    unit_price: Annotated[Optional[float], pydantic.Field(alias="unitPrice")] = None
    r"""The price of one unit of the goods"""

    total_price: Annotated[Optional[float], pydantic.Field(alias="totalPrice")] = None
    r"""The total price of the line item, including additional charges and discounts"""

    currency: Optional[str] = None
    r"""The currency of the line item"""

    net_weight: Annotated[Optional[float], pydantic.Field(alias="netWeight")] = None
    r"""The net weight of the line item (that is, without the packaging)"""

    net_weight_uom: Annotated[Optional[str], pydantic.Field(alias="netWeightUom")] = (
        None
    )
    r"""The unit of measurement used for the net weight"""

    gross_weight: Annotated[Optional[float], pydantic.Field(alias="grossWeight")] = None
    r"""The gross weight of the line item (that is, with the packaging)"""

    gross_weight_uom: Annotated[
        Optional[str], pydantic.Field(alias="grossWeightUom")
    ] = None
    r"""The unit of measurement used for the gross weight"""


class CommercialInvoiceFieldsTypedDict(TypedDict):
    r"""Fields extracted from a commercial invoice"""

    consignee: NotRequired[CommercialInvoiceFieldsConsigneeTypedDict]
    vendor: NotRequired[CommercialInvoiceFieldsVendorTypedDict]
    ship_to: NotRequired[CommercialInvoiceFieldsShipToTypedDict]
    bill_to: NotRequired[CommercialInvoiceFieldsBillToTypedDict]
    invoice_number: NotRequired[str]
    r"""The number of the invoice"""
    invoice_date: NotRequired[date]
    r"""The date on which the invoice was issued"""
    due_date: NotRequired[date]
    r"""The date by which the invoice should be paid"""
    country_of_origin: NotRequired[str]
    r"""The country where the goods were manufactured"""
    country_of_export: NotRequired[str]
    r"""The country from which the goods are being exported"""
    country_of_destination: NotRequired[str]
    r"""The country into which the goods are being imported"""
    inco_term: NotRequired[str]
    r"""The terms of shipment"""
    weight: NotRequired[float]
    r"""The total weight of the goods"""
    weight_uom: NotRequired[str]
    r"""The unit of measurement used for the weight of the goods"""
    total_pallets: NotRequired[float]
    r"""The total number of pallets containing the goods"""
    total: NotRequired[float]
    r"""The total price of the goods"""
    currency: NotRequired[str]
    r"""The currency of the price"""
    additional_costs: NotRequired[List[CommercialInvoiceFieldsAdditionalCostsTypedDict]]
    line_items: NotRequired[List[CommercialInvoiceFieldsLineItemsTypedDict]]


class CommercialInvoiceFields(BaseModel):
    r"""Fields extracted from a commercial invoice"""

    consignee: Optional[CommercialInvoiceFieldsConsignee] = None

    vendor: Optional[CommercialInvoiceFieldsVendor] = None

    ship_to: Annotated[
        Optional[CommercialInvoiceFieldsShipTo], pydantic.Field(alias="shipTo")
    ] = None

    bill_to: Annotated[
        Optional[CommercialInvoiceFieldsBillTo], pydantic.Field(alias="billTo")
    ] = None

    invoice_number: Annotated[Optional[str], pydantic.Field(alias="invoiceNumber")] = (
        None
    )
    r"""The number of the invoice"""

    invoice_date: Annotated[Optional[date], pydantic.Field(alias="invoiceDate")] = None
    r"""The date on which the invoice was issued"""

    due_date: Annotated[Optional[date], pydantic.Field(alias="dueDate")] = None
    r"""The date by which the invoice should be paid"""

    country_of_origin: Annotated[
        Optional[str], pydantic.Field(alias="countryOfOrigin")
    ] = None
    r"""The country where the goods were manufactured"""

    country_of_export: Annotated[
        Optional[str], pydantic.Field(alias="countryOfExport")
    ] = None
    r"""The country from which the goods are being exported"""

    country_of_destination: Annotated[
        Optional[str], pydantic.Field(alias="countryOfDestination")
    ] = None
    r"""The country into which the goods are being imported"""

    inco_term: Annotated[Optional[str], pydantic.Field(alias="incoTerm")] = None
    r"""The terms of shipment"""

    weight: Optional[float] = None
    r"""The total weight of the goods"""

    weight_uom: Annotated[Optional[str], pydantic.Field(alias="weightUom")] = None
    r"""The unit of measurement used for the weight of the goods"""

    total_pallets: Annotated[Optional[float], pydantic.Field(alias="totalPallets")] = (
        None
    )
    r"""The total number of pallets containing the goods"""

    total: Optional[float] = None
    r"""The total price of the goods"""

    currency: Optional[str] = None
    r"""The currency of the price"""

    additional_costs: Annotated[
        Optional[List[CommercialInvoiceFieldsAdditionalCosts]],
        pydantic.Field(alias="additionalCosts"),
    ] = None

    line_items: Annotated[
        Optional[List[CommercialInvoiceFieldsLineItems]],
        pydantic.Field(alias="lineItems"),
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from .hotelinvoicefields import HotelInvoiceFields, HotelInvoiceFieldsTypedDict
from abbyy_document_ai.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class HotelInvoiceValidationErrorsTypedDict(TypedDict):
    message: str


class HotelInvoiceValidationErrors(BaseModel):
    message: str


class HotelInvoiceTypedDict(TypedDict):
    r"""Extracted Hotel Invoice Data Response"""

    meta: DocumentTypedDict
    r"""Represents a document that has been submitted for processing."""
    fields: NotRequired[HotelInvoiceFieldsTypedDict]
    r"""Fields extracted from a hotel invoice"""
    validation_errors: NotRequired[List[HotelInvoiceValidationErrorsTypedDict]]
    r"""An array of validation errors that occurred while processing the document. These typically do not prevent field extraction, but rather indicate issues extracting key fields."""


class HotelInvoice(BaseModel):
    r"""Extracted Hotel Invoice Data Response"""

    meta: Document
    r"""Represents a document that has been submitted for processing."""

    fields: Optional[HotelInvoiceFields] = None
    r"""Fields extracted from a hotel invoice"""

    validation_errors: Annotated[
        Optional[List[HotelInvoiceValidationErrors]],
        pydantic.Field(alias="validationErrors"),
    ] = None
    r"""An array of validation errors that occurred while processing the document. These typically do not prevent field extraction, but rather indicate issues extracting key fields."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from typing_extensions import TypedDict


class URLInputSourceTypedDict(TypedDict):
    r"""Input the URL of a remote file."""

    url: str
    r"""The URL of the remote file"""


class URLInputSource(BaseModel):
    r"""Input the URL of a remote file."""

    url: str
    r"""The URL of the remote file"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
from enum import Enum
import pydantic
from typing import List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class HotelInvoiceFieldsTaxesTypedDict(TypedDict):
    tax_rate: NotRequired[float]
    r"""The tax rate applied to the purchase."""
    tax_amount: NotRequired[float]
    r"""The amount of tax for this rate."""


class HotelInvoiceFieldsTaxes(BaseModel):
    tax_rate: Annotated[Optional[float], pydantic.Field(alias="taxRate")] = None
    r"""The tax rate applied to the purchase."""

    tax_amount: Annotated[Optional[float], pydantic.Field(alias="taxAmount")] = None
    r"""The amount of tax for this rate."""


class Five(str, Enum):
    UNDEFINED = "Undefined"


class Four(str, Enum):
    MIXED = "Mixed"


class Three(str, Enum):
    TRANSFER = "Transfer"


class Two(str, Enum):
    CASH = "Cash"


class One(str, Enum):
    CARD = "Card"


PaymentMethodTypedDict = TypeAliasType(
    "PaymentMethodTypedDict", Union[One, Two, Three, Four, Five]
)
r"""Payment method used for the transaction."""


PaymentMethod = TypeAliasType("PaymentMethod", Union[One, Two, Three, Four, Five])
r"""Payment method used for the transaction."""


class CardType5(str, Enum):
    UNDEFINED = "Undefined"


class CardType4(str, Enum):
    NATIONAL_CARD = "NationalCard"


class CardType3(str, Enum):
    AMERICAN_EXPRESS = "AmericanExpress"


class CardType2(str, Enum):
    VISA = "VISA"


class CardType1(str, Enum):
    MASTERCARD = "Mastercard"


CardTypeTypedDict = TypeAliasType(
    "CardTypeTypedDict", Union[CardType1, CardType2, CardType3, CardType4, CardType5]
)
r"""The payment processing network of the card used for payment."""


CardType = TypeAliasType(
    "CardType", Union[CardType1, CardType2, CardType3, CardType4, CardType5]
)
r"""The payment processing network of the card used for payment."""


class CreditOrDebit2(str, Enum):
    DEBIT = "Debit"


class CreditOrDebit1(str, Enum):
    CREDIT = "Credit"


CreditOrDebitTypedDict = TypeAliasType(
    "CreditOrDebitTypedDict", Union[CreditOrDebit1, CreditOrDebit2]
)
r"""Whether a credit or debit card was used."""


CreditOrDebit = TypeAliasType("CreditOrDebit", Union[CreditOrDebit1, CreditOrDebit2])
r"""Whether a credit or debit card was used."""


class HotelInvoiceFieldsLineItemsTypedDict(TypedDict):
    sku: NotRequired[str]
    r"""The stock-keeping unit identifier of services or items provided to the guest."""
    description: NotRequired[str]
    r"""The name of the purchased service or item."""
    quantity: NotRequired[float]
    r"""The quantity of the service or item purchased."""
    price: NotRequired[float]
    r"""The price per unit."""
    amount: NotRequired[float]
    r"""The total amount in the line item."""


class HotelInvoiceFieldsLineItems(BaseModel):
    sku: Optional[str] = None
    r"""The stock-keeping unit identifier of services or items provided to the guest."""

    description: Optional[str] = None
    r"""The name of the purchased service or item."""

    quantity: Optional[float] = None
    r"""The quantity of the service or item purchased."""

    price: Optional[float] = None
    r"""The price per unit."""

    amount: Optional[float] = None
    r"""The total amount in the line item."""


class HotelInvoiceFieldsTypedDict(TypedDict):
    r"""Fields extracted from a hotel invoice"""

    date_: NotRequired[date]
    r"""The date when the invoice was issued by the hotel."""
    check_in_date: NotRequired[date]
    r"""The date when the guest checked into the hotel."""
    check_out_date: NotRequired[date]
    r"""The date when the guest checked out of the hotel."""
    nights: NotRequired[float]
    r"""The duration of the guest's stay."""
    hotel_name: NotRequired[str]
    r"""The name of the hotel."""
    address: NotRequired[str]
    r"""The address of the hotel."""
    city: NotRequired[str]
    r"""The city where the hotel is located."""
    state: NotRequired[str]
    r"""The state/province where the hotel is located."""
    postal_code: NotRequired[str]
    r"""The postal code of the hotel's address."""
    country: NotRequired[str]
    r"""The country where the hotel is located."""
    phone: NotRequired[str]
    r"""The phone number of the hotel."""
    currency: NotRequired[str]
    r"""The currency of the payment."""
    total: NotRequired[float]
    r"""The total amount of the invoice."""
    tax_total: NotRequired[float]
    r"""The total amount of tax levied on the purchase."""
    taxes: NotRequired[List[HotelInvoiceFieldsTaxesTypedDict]]
    payment_method: NotRequired[PaymentMethodTypedDict]
    r"""Payment method used for the transaction."""
    card_type: NotRequired[CardTypeTypedDict]
    r"""The payment processing network of the card used for payment."""
    credit_or_debit: NotRequired[CreditOrDebitTypedDict]
    r"""Whether a credit or debit card was used."""
    card_number: NotRequired[str]
    r"""The number of the card used for payment. May be partially masked."""
    line_items: NotRequired[List[HotelInvoiceFieldsLineItemsTypedDict]]


class HotelInvoiceFields(BaseModel):
    r"""Fields extracted from a hotel invoice"""

    date_: Annotated[Optional[date], pydantic.Field(alias="date")] = None
    r"""The date when the invoice was issued by the hotel."""

    check_in_date: Annotated[Optional[date], pydantic.Field(alias="checkInDate")] = None
    r"""The date when the guest checked into the hotel."""

    check_out_date: Annotated[Optional[date], pydantic.Field(alias="checkOutDate")] = (
        None
    )
    r"""The date when the guest checked out of the hotel."""

    nights: Optional[float] = None
    r"""The duration of the guest's stay."""

    hotel_name: Annotated[Optional[str], pydantic.Field(alias="hotelName")] = None
    r"""The name of the hotel."""

    address: Optional[str] = None
    r"""The address of the hotel."""

    city: Optional[str] = None
    r"""The city where the hotel is located."""

    state: Optional[str] = None
    r"""The state/province where the hotel is located."""

    postal_code: Annotated[Optional[str], pydantic.Field(alias="postalCode")] = None
    r"""The postal code of the hotel's address."""

    country: Optional[str] = None
    r"""The country where the hotel is located."""

    phone: Optional[str] = None
    r"""The phone number of the hotel."""

    currency: Optional[str] = None
    r"""The currency of the payment."""

    total: Optional[float] = None
    r"""The total amount of the invoice."""

    tax_total: Annotated[Optional[float], pydantic.Field(alias="taxTotal")] = None
    r"""The total amount of tax levied on the purchase."""

    taxes: Optional[List[HotelInvoiceFieldsTaxes]] = None

    payment_method: Annotated[
        Optional[PaymentMethod], pydantic.Field(alias="paymentMethod")
    ] = None
    r"""Payment method used for the transaction."""

    card_type: Annotated[Optional[CardType], pydantic.Field(alias="cardType")] = None
    r"""The payment processing network of the card used for payment."""

    credit_or_debit: Annotated[
        Optional[CreditOrDebit], pydantic.Field(alias="creditOrDebit")
    ] = None
    r"""Whether a credit or debit card was used."""

    card_number: Annotated[Optional[str], pydantic.Field(alias="cardNumber")] = None
    r"""The number of the card used for payment. May be partially masked."""

    line_items: Annotated[
        Optional[List[HotelInvoiceFieldsLineItems]], pydantic.Field(alias="lineItems")
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from abbyy_document_ai.types import BaseModel
from typing_extensions import TypedDict


class ConversionResultsTypedDict(TypedDict):
    r"""The response from the `getConversionResults` endpoint."""

    meta: DocumentTypedDict
    r"""Represents a document that has been submitted for processing."""


class ConversionResults(BaseModel):
    r"""The response from the `getConversionResults` endpoint."""

    meta: Document
    r"""Represents a document that has been submitted for processing."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class URLListInputSourceTypedDict(TypedDict):
    r"""Input the URLs of multiple remote files."""

    urls: List[str]


class URLListInputSource(BaseModel):
    r"""Input the URLs of multiple remote files."""

    urls: List[str]
